_positive = set(
    [
        "abba",
        "habilitat",
        "NO TRANSLATION",
        "absolut",
        "absolució",
        "absorbit",
        "abundant",
        "acadèmic",
        "acadèmia",
        "acceptable",
        "acceptació",
        "accessible",
        "acolliment",
        "allotjament",
        "acompanyament",
        "aconseguir",
        "realitzat",
        "realització",
        "acord",
        "responsabilitat",
        "responsable",
        "acreditat",
        "NO TRANSLATION",
        "precís",
        "as",
        "aconseguir",
        "assoliment",
        "reconeixement",
        "adquirir",
        "adquirint",
        "Acrobat",
        "acció",
        "actual",
        "agudesa",
        "acumen",
        "adaptar",
        "adaptable",
        "adreces",
        "adepte",
        "NO TRANSLATION",
        "adjunt",
        "admirable",
        "almirall",
        "admiració",
        "admirar",
        "admirador",
        "admissible",
        "adorable",
        "adoració",
        "adorar",
        "avance",
        "avançat",
        "avenç",
        "avantatge",
        "avantatjós",
        "avinguda",
        "aventura",
        "aventurer",
        "recomanable",
        "aconsellar",
        "assessor",
        "advocacia",
        "estètic",
        "estètica",
        "afable",
        "afecte",
        "afiliat",
        "afirmar",
        "afirmació",
        "afirmatiu",
        "afirmativament",
        "riquesa",
        "afluent",
        "pagar",
        "NO TRANSLATION",
        "àgil",
        "agilitat",
        "acordar",
        "agradable",
        "convingut",
        "acordant",
        "acord",
        "agricultura",
        "endavant",
        "ajudes",
        "ajudant",
        "alabastre",
        "vigilància",
        "NO TRANSLATION",
        "viu",
        "allau",
        "lleialtat",
        "allegro",
        "alleujar",
        "alleujament",
        "aliats",
        "admissible",
        "encant",
        "fascinant",
        "aliat",
        "Totpoderós",
        "aloha",
        "sorprenentment",
        "ambaixador",
        "ambició",
        "Millorar",
        "amen",
        "amenable",
        "esmenar",
        "esmena",
        "comoditat",
        "amable",
        "amistós",
        "amnistia",
        "NO TRANSLATION",
        "divertir",
        "divertit",
        "diversió",
        "divertit",
        "analista",
        "àncora",
        "ancoratge",
        "àngel",
        "angelical",
        "animar",
        "animat",
        "antibiòtics",
        "antídot",
        "antifúngic",
        "antic",
        "antisèptic",
        "aplom",
        "apologètic",
        "demaneu disculpes",
        "disculpa",
        "apòstol",
        "aplaudiments",
        "apreciació",
        "aprovació",
        "aprovació",
        "aprovar",
        "aprovant",
        "apt",
        "aptitud",
        "arqueologia",
        "ardent",
        "ardor",
        "aristocràcia",
        "aristocràtic",
        "armadura",
        "aroma",
        "despertar",
        "matriu",
        "art",
        "articular",
        "articulació",
        "artesà",
        "NO TRANSLATION",
        "artístic",
        "ascendència",
        "pujada",
        "aspiració",
        "aspirar",
        "aspirant",
        "muntatge",
        "assentiment",
        "afirmant",
        "actius",
        "ajudar",
        "assistència",
        "associar",
        "assuage",
        "garantia",
        "assegurat",
        "NO TRANSLATION",
        "sorpresa",
        "astròleg",
        "astronauta",
        "astrònom",
        "astut",
        "atleta",
        "atlètic",
        "àtom",
        "atone",
        "expiació",
        "adjunció",
        "assolible",
        "assoliment",
        "assistent",
        "atenció",
        "atent",
        "testifiqui",
        "advocat",
        "atracció",
        "atractiu",
        "augment",
        "Agost",
        "tia",
        "aura",
        "auspicis",
        "autèntic",
        "autenticitat",
        "autor",
        "autoritari",
        "autoritat",
        "autorització",
        "autoritzat",
        "avatar",
        "premi",
        "ai",
        "Aye",
        "bebè",
        "Batxillerat",
        "columna vertebral",
        "equilibri",
        "equilibrat",
        "balada",
        "ballet",
        "butlletí electoral",
        "bàlsam",
        "banquet",
        "baptisme",
        "baptismal",
        "bard",
        "ganga",
        "bàsquet",
        "baluard",
        "bany",
        "biga",
        "beaming",
        "embelliment",
        "bonic",
        "embellir",
        "bellesa",
        "roca de fons",
        "cervesa",
        "convenient",
        "amic",
        "creient",
        "benefactor",
        "beneficiós",
        "benefici",
        "benevolència",
        "benigne",
        "llitera",
        "compromès",
        "millorament",
        "beguda",
        "bíblica",
        "bilingüe",
        "naixement",
        "aniversari",
        "sense culpa",
        "beneeixi",
        "beneït",
        "benedicció",
        "benediccions",
        "felicitat",
        "feliç",
        "sense sang",
        "florir",
        "florir",
        "guardaespatlles",
        "en negreta",
        "audàcia",
        "reforçar",
        "Bonança",
        "NO TRANSLATION",
        "bonificació",
        "llibertat",
        "llibreria",
        "boon",
        "abundant",
        "generositat",
        "ram",
        "cervells",
        "valentia",
        "esmorzar",
        "nupcial",
        "núvia",
        "nuvi",
        "dama d'honor",
        "alegre",
        "brillantor",
        "genial",
        "brocat",
        "germà",
        "confraria",
        "fraternal",
        "amic",
        "construir",
        "edifici",
        "bulldog",
        "a prova de bales",
        "boia",
        "buss",
        "majordom",
        "mantega",
        "buxom",
        "brunzit",
        "cabina",
        "gabinet",
        "cafè",
        "calculadora",
        "becerro",
        "calma",
        "canari",
        "sincer",
        "candidat",
        "confitat",
        "capitalista",
        "capità",
        "cautivar",
        "cautivant",
        "carrera",
        "amb compte",
        "acuradament",
        "carícia",
        "cuidador",
        "carol",
        "cascada",
        "efectiu",
        "categòric",
        "atendre",
        "catàrtica",
        "catedral",
        "cautelós",
        "amb cautela",
        "celebrat",
        "celebrant",
        "celebració",
        "celestial",
        "centre",
        "centurió",
        "cerebral",
        "cerimònia",
        "certesa",
        "president",
        "presidenta",
        "campió",
        "chant",
        "carregador",
        "caritatiu",
        "caritat",
        "encant",
        "encantador",
        "castedat",
        "xerraire",
        "llista de verificació",
        "alegria",
        "alegre",
        "alegria",
        "animant",
        "NO TRANSLATION",
        "químic",
        "estimar",
        "cirera",
        "capità",
        "nen",
        "infància",
        "chirp",
        "cincel",
        "cavalleria",
        "xocolata",
        "elecció",
        "cor",
        "coral",
        "cor",
        "triat",
        "sopa",
        "crònica",
        "riure",
        "Església",
        "sidra",
        "circumcisió",
        "ciutadà",
        "civil",
        "civilitat",
        "civilització",
        "civilitzat",
        "clarivident",
        "aplaudir",
        "aclarir",
        "clàssic",
        "clàssic",
        "clàssics",
        "classificar",
        "net",
        "neteja",
        "neteja",
        "net",
        "netejar",
        "neteja",
        "aclariment",
        "claredat",
        "clerical",
        "intel·ligent",
        "intel·ligència",
        "clímax",
        "proximitat",
        "tancament",
        "NO TRANSLATION",
        "pallasso",
        "coalició",
        "Costa",
        "coexistir",
        "còmode",
        "cognitiu",
        "coherència",
        "coherent",
        "cohesiu",
        "col·lectivament",
        "coronel",
        "colossal",
        "confort",
        "comandant",
        "comandant",
        "commemorar",
        "commemoració",
        "commemoratiu",
        "felicitar",
        "encomiable",
        "comentarista",
        "compromès",
        "commodore",
        "commonwealth",
        "comunicar-se",
        "comunicatiu",
        "comunió",
        "comunitat",
        "commutació",
        "commutar",
        "company",
        "compassió",
        "compassiu",
        "compatibilitat",
        "compatible",
        "convincent",
        "compensar",
        "compensatori",
        "competència",
        "competència",
        "competent",
        "complaença",
        "complement",
        "complementari",
        "completament",
        "integritat",
        "completant",
        "finalització",
        "compliment",
        "compatible",
        "NO TRANSLATION",
        "compost",
        "compositor",
        "compost",
        "comprendre",
        "complet",
        "camarada",
        "concèntric",
        "conciliació",
        "concloent",
        "concòrdia",
        "concordança",
        "condol",
        "condonar",
        "conducta",
        "conductivitat",
        "Confederat",
        "confiança",
        "confiat",
        "confirmat",
        "conformitat",
        "agradable",
        "felicitacions",
        "congregació",
        "congruència",
        "coneixedor",
        "consciència",
        "conscient",
        "consciència",
        "consagració",
        "conservació",
        "conservar",
        "considerable",
        "considerat",
        "consistència",
        "consola",
        "consonant",
        "constància",
        "constant",
        "constitucional",
        "construir",
        "consumat",
        "contacte",
        "contemplació",
        "contingut",
        "continueu",
        "contorn",
        "contribueix",
        "col·laborador",
        "comoditat",
        "convenient",
        "convent",
        "Convenció",
        "conversant",
        "conversacional",
        "convertir",
        "convencer",
        "guai",
        "frescor",
        "cooperar",
        "cooperant",
        "cooperació",
        "cooperativa",
        "nucli central",
        "coronació",
        "corporació",
        "corpori",
        "corrector",
        "correspondència",
        "corroborar",
        "cosmopolita",
        "acollidor",
        "consell",
        "Consell",
        "conseller",
        "comptar",
        "comtessa",
        "valentia",
        "valent",
        "cortès",
        "cortesia",
        "festeig",
        "Cala",
        "pacte",
        "bressol",
        "artesania",
        "artesà",
        "crema",
        "crear",
        "creatiu",
        "credibilitat",
        "credencials",
        "credibilitat",
        "creïble",
        "crèdit",
        "NO TRANSLATION",
        "acreditat",
        "crescendo",
        "crítica",
        "coronació",
        "crucial",
        "vidre",
        "abraçar",
        "culinari",
        "culminació",
        "conrear",
        "cultivat",
        "cultiu",
        "cultura",
        "curable",
        "curiositat",
        "curl",
        "coixí",
        "client",
        "bonic",
        "maduixes",
        "Dame",
        "dansa",
        "atrevit",
        "estimat",
        "corrent",
        "filla",
        "alba",
        "acord",
        "estimat",
        "debat",
        "decència",
        "decent",
        "declaratiu",
        "dedicació",
        "defensar",
        "defensat",
        "defensor",
        "defensant",
        "defensa",
        "deferència",
        "definitiva",
        "grau",
        "delectable",
        "delegat",
        "deliberada",
        "deliciós",
        "delícia",
        "encantat",
        "deliciós",
        "alliberament",
        "lliurament",
        "democràcia",
        "demostrable",
        "demostratiu",
        "profunditat",
        "descriptiu",
        "mereixen",
        "merescut",
        "dissenyador",
        "desitjable",
        "desitjant",
        "desitjós",
        "destinació",
        "detectar",
        "detecció",
        "determinació",
        "determinat",
        "desenvolupar",
        "devocional",
        "devot",
        "destresa",
        "diamant",
        "diari",
        "diccionari",
        "didàctica",
        "dietètic",
        "digna",
        "dignitat",
        "diligència",
        "sopar",
        "diplomàcia",
        "diplomàtic",
        "director",
        "descobriment",
        "NO TRANSLATION",
        "discreció",
        "discrecional",
        "discussió",
        "desinfecció",
        "disposat",
        "divulgar",
        "destil·lació",
        "distinció",
        "impecable",
        "diversificat",
        "diversió",
        "divinitat",
        "metge",
        "hacedor",
        "perseguit",
        "dofí",
        "don",
        "donació",
        "sens dubte",
        "colom",
        "avall",
        "duo",
        "duc",
        "durabilitat",
        "durador",
        "obedient",
        "ansiós",
        "afany",
        "comte",
        "guanyar",
        "seriós",
        "amb fervor",
        "serietat",
        "facilitat",
        "servitud",
        "NO TRANSLATION",
        "menjar",
        "Èxtasi",
        "ecstàtic",
        "edificació",
        "educar",
        "educat",
        "educatiu",
        "eficaç",
        "eficàcia",
        "eficiència",
        "eficient",
        "esforç",
        "ejaculació",
        "elaboració",
        "ansiós",
        "ancià",
        "ancians",
        "electe",
        "elèctric",
        "electricitat",
        "elegància",
        "elegant",
        "elevació",
        "elegibles",
        "elit",
        "eloqüència",
        "eloqüent",
        "aclarir",
        "emancipació",
        "abraçada",
        "emèrit",
        "eminència",
        "eminent",
        "eminentment",
        "NO TRANSLATION",
        "empatia",
        "autoritzar",
        "emular",
        "habilitar",
        "habilitació",
        "encantar",
        "encantat",
        "encantador",
        "NO TRANSLATION",
        "animar",
        "ànim",
        "enciclopèdia",
        "esforç",
        "dotar",
        "dotat",
        "dotació",
        "resistència",
        "resistir",
        "enèrgic",
        "compromesos",
        "atractiu",
        "millorar",
        "gaudir",
        "gaudint",
        "il·luminar",
        "il·luminació",
        "animat",
        "enriquir",
        "conjunt",
        "estendard",
        "emprenedor",
        "entretenir",
        "entretingut",
        "entretingut",
        "entreteniment",
        "entusiasme",
        "entusiasta",
        "NO TRANSLATION",
        "efemèrides",
        "èpica",
        "epitome",
        "igualtat",
        "igualment",
        "equilibri",
        "equitat",
        "encàrrec",
        "erudit",
        "esprit",
        "essencial",
        "establert",
        "estima",
        "estètica",
        "ètic",
        "ètica",
        "de fulla perenne",
        "etern",
        "evident",
        "evolució",
        "exaltar",
        "exaltació",
        "exaltada",
        "superar",
        "sobresortir",
        "excel·lència",
        "excel · lent",
        "intercanvi",
        "excitable",
        "excitació",
        "excitar",
        "emocionat",
        "emoció",
        "emocionant",
        "exemplar",
        "exempció",
        "alegria",
        "exhortar",
        "exhortació",
        "existència",
        "exòtic",
        "espera",
        "expectativa",
        "expedient",
        "expedició",
        "experimentat",
        "expert",
        "experiència",
        "explica",
        "exquisit",
        "exquisitament",
        "estendre",
        "extensiu",
        "extra",
        "extraordinari",
        "extricate",
        "exuberància",
        "facilitar",
        "fets",
        "professorat",
        "NO TRANSLATION",
        "Fira",
        "amb força",
        "fe",
        "fidels",
        "fama",
        "familiar",
        "familiaritat",
        "famós",
        "famós",
        "luxós",
        "fanfàrria",
        "fascinant",
        "fascinació",
        "de moda",
        "sense culpa",
        "favorable",
        "favorit",
        "favoritisme",
        "sense por",
        "feat",
        "funció",
        "felicitat",
        "company",
        "beques",
        "femella",
        "fèrtil",
        "fervor",
        "Festival",
        "festiu",
        "NO TRANSLATION",
        "fidelitat",
        "festa",
        "finalment",
        "galetes",
        "delicadesa",
        "bola de foc",
        "ignífug",
        "fermesa",
        "NO TRANSLATION",
        "ajust",
        "fixació",
        "halagador",
        "flota",
        "flexibilitat",
        "floral",
        "flux",
        "florida",
        "rubor",
        "volant",
        "enfocament",
        "afecte",
        "menjar",
        "futbol",
        "paciència",
        "primer pla",
        "avantpassats",
        "precedent",
        "capatàs",
        "precursor",
        "preveure",
        "previst",
        "previsió",
        "forjar",
        "perdonar",
        "perdonat",
        "perdonar",
        "formatiu",
        "fórmula",
        "NO TRANSLATION",
        "pròxim",
        "fortificar",
        "fortitud",
        "fortalesa",
        "afortunat",
        "fortuna",
        "endavant",
        "trobat",
        "fundació",
        "fragant",
        "Franc",
        "franquesa",
        "fraternal",
        "llibertat",
        "lliurement",
        "amic",
        "amabilitat",
        "amable",
        "amistat",
        "frisky",
        "esgarrifós",
        "frugal",
        "fructífer",
        "complir",
        "realització",
        "ple",
        "completament",
        "diversió",
        "fonamental",
        "fusible",
        "fusió",
        "guany",
        "guanyant",
        "galant",
        "Gallantry",
        "en abundància",
        "jardí",
        "granat",
        "guarnició",
        "gazette",
        "engranatge",
        "gemma",
        "general",
        "generositat",
        "generós",
        "genial",
        "geni",
        "gentil",
        "senyor",
        "gentilesa",
        "senyoreta",
        "genuí",
        "Geranium",
        "regal",
        "dotada",
        "gegantí",
        "riureu",
        "girder",
        "donant",
        "alegre",
        "alegria",
        "alegria",
        "lliscar",
        "glimmer",
        "brillant",
        "glorificació",
        "glorificar",
        "glòria",
        "brillantor",
        "brillar",
        "brillant",
        "Déu",
        "piadoso",
        "godsend",
        "or",
        "bo",
        "molt bé",
        "bondat",
        "béns",
        "bona voluntat",
        "preciosa",
        "evangeli",
        "governar",
        "gràcia",
        "agraciat",
        "amable",
        "amb gràcia",
        "graduació",
        "néts",
        "grandesa",
        "àvia",
        "subvenció",
        "concedit",
        "agraït",
        "gratificar",
        "gratitud",
        "major",
        "grandesa",
        "verd",
        "salutació",
        "gregari",
        "sonrisa",
        "grist",
        "gra",
        "base",
        "créixer",
        "creixement",
        "garantia",
        "guàrdia",
        "guardià",
        "tutela",
        "governador",
        "guia",
        "guia",
        "guia",
        "guru",
        "budells",
        "gimnasta",
        "habitat",
        "Hale",
        "pràctic",
        "feliçment",
        "felicitat",
        "feliç",
        "resistent",
        "harmoniosament",
        "harmonia",
        "collita",
        "refugi",
        "avanç",
        "curar",
        "curació",
        "saludable",
        "saludable",
        "sincera",
        "llar de foc",
        "de cor",
        "celestial",
        "cels",
        "heft",
        "casc",
        "ajudant",
        "útil",
        "herbes",
        "heroi",
        "heroic",
        "heroics",
        "heroïna",
        "heroisme",
        "apogeu",
        "hilarant",
        "hilaritat",
        "llogar",
        "afició",
        "festa",
        "santedat",
        "Sant",
        "homenatge",
        "homologia",
        "honesta",
        "honestedat",
        "mel",
        "lluna de mel",
        "honor",
        "honorable",
        "esperança",
        "esperançat",
        "horitzó",
        "hospitalitat",
        "llar",
        "servei de neteja",
        "abraçada",
        "humà",
        "humanitari",
        "humanitat",
        "humiliat",
        "humilment",
        "humilitat",
        "humorista",
        "humorístic",
        "hurra",
        "ramaderia",
        "silenci",
        "cabana",
        "higiènic",
        "himne",
        "idealisme",
        "ídol",
        "NO TRANSLATION",
        "il·luminació",
        "il·lustrar",
        "il·lustre",
        "imaginatiu",
        "immaculada",
        "immens",
        "submergir",
        "immortal",
        "impartir",
        "imparcial",
        "imparcialitat",
        "impecable",
        "impermeable",
        "importància",
        "important",
        "impressionar",
        "impressió",
        "millorar",
        "millorat",
        "millora",
        "millorant",
        "Improvisar",
        "inalienable",
        "inauguració",
        "incisiu",
        "incloure",
        "inclòs",
        "incloent",
        "inclusiu",
        "augmentar",
        "indeleble",
        "indemnitat",
        "independència",
        "indestructible",
        "individualitat",
        "indomable",
        "inefable",
        "barat",
        "infalible",
        "infant",
        "infinit",
        "infinit",
        "influent",
        "informació",
        "enginyós",
        "herència",
        "inimitable",
        "innocència",
        "innocent",
        "innocentment",
        "innocu",
        "innovar",
        "innovació",
        "inquirer",
        "investigació",
        "inquisitiva",
        "inseparable",
        "insígnies",
        "inspector",
        "inspiració",
        "inspirar",
        "inspirat",
        "instintiva",
        "instruir",
        "instrucció",
        "instructor",
        "instrumental",
        "assegurar",
        "intacte",
        "integritat",
        "intel·lecte",
        "intel · lectual",
        "intel·ligència",
        "intel · ligent",
        "destinat",
        "acte sexual",
        "interès",
        "interessat",
        "interessant",
        "interior",
        "interlocutorial",
        "interludio",
        "íntim",
        "entonació",
        "intrèpid",
        "intuïció",
        "intuïtiu",
        "invariablement",
        "inventiva",
        "inventor",
        "investigar",
        "dinamitzar",
        "invitació",
        "convidar",
        "convidant",
        "ferro",
        "irreductible",
        "irrefutable",
        "jackpot",
        "melmelada",
        "NO TRANSLATION",
        "treball",
        "unir-se",
        "unit",
        "bromista",
        "fent broma",
        "periodista",
        "viatge",
        "jovial",
        "alegria",
        "alegre",
        "alegre",
        "jubilant",
        "jubileu",
        "judicial",
        "prudent",
        "saltar",
        "justícia",
        "justificable",
        "justificació",
        "record",
        "ken",
        "keynote",
        "pedra angular",
        "amable",
        "bondat",
        "familiar",
        "rei",
        "besar",
        "gatet",
        "knack",
        "cavaller",
        "sabent",
        "coneixement",
        "felicitats",
        "mà d'obra",
        "xai",
        "terra",
        "aterrat",
        "làser",
        "lloable",
        "riure",
        "rient",
        "riure",
        "llançament",
        "laureado",
        "llorer",
        "laureles",
        "genial",
        "lícit",
        "dirigir",
        "líder",
        "lliga",
        "aprendre",
        "aprenentatge",
        "professor",
        "marge de marge",
        "legal",
        "legalitzat",
        "llegendari",
        "llegibilitat",
        "llegible",
        "oci",
        "tranquil",
        "lema",
        "indulgent",
        "lliçó",
        "lletrats",
        "nivell",
        "apalancament",
        "alliberar",
        "alliberament",
        "llibertat",
        "biblioteca",
        "ànima vital",
        "far",
        "a gust",
        "lingüista",
        "lleó",
        "lithe",
        "lògic",
        "longevitat",
        "senyoria",
        "amable",
        "amor",
        "preciosa",
        "NO TRANSLATION",
        "amant",
        "estimant",
        "lleial",
        "lleialtat",
        "sort",
        "afortunat",
        "luscious",
        "brillantor",
        "brillant",
        "exuberant",
        "luxós",
        "luxe",
        "lira",
        "líric",
        "màgic",
        "imant",
        "magnetisme",
        "magnetita",
        "magnificència",
        "magnífic",
        "donzella",
        "principal",
        "pilar",
        "majestuós",
        "majestat",
        "major",
        "majoria",
        "gestionar",
        "gestió",
        "mandarin",
        "manhood",
        "es manifesta",
        "varonil",
        "mannà",
        "educat",
        "maneres",
        "fabricant",
        "marxa",
        "marcat",
        "comercialitzable",
        "marquès",
        "matrimoni",
        "medul · la",
        "casar-se",
        "mariscal",
        "meravella",
        "meravellós",
        "de meravella",
        "masculí",
        "massatge",
        "mestre",
        "obra mestra",
        "domini",
        "company",
        "matrimonis",
        "matrona",
        "màxim",
        "alcalde",
        "prat",
        "mesurat",
        "medalla",
        "mediteu",
        "mediació",
        "mediador",
        "mèdic",
        "NO TRANSLATION",
        "mediterrània",
        "medley",
        "record",
        "memorable",
        "reparació",
        "menstruacions",
        "mentor",
        "misericordiós",
        "gràcies",
        "fusionar",
        "mèrit",
        "meritori",
        "alegria",
        "alegre",
        "metropolitana",
        "esmorteir",
        "microscòpia",
        "obstrucció",
        "poderós",
        "mime",
        "atent",
        "consciència",
        "Ministeri",
        "miracle",
        "miraculós",
        "alegria",
        "missioner",
        "model",
        "moderat",
        "moderador",
        "Modest",
        "modèstia",
        "momentum",
        "monetari",
        "diners",
        "monjo",
        "monument",
        "moral",
        "moralitat",
        "moral",
        "morter",
        "maternitat",
        "motiu",
        "mòbil",
        "moure",
        "muscular",
        "música",
        "musical",
        "mutable",
        "mútua",
        "migdiada",
        "naturalista",
        "navegable",
        "perfectament",
        "nèctar",
        "agulla",
        "negociar",
        "negociador",
        "veí",
        "nervi",
        "nestle",
        "noblesa",
        "noble",
        "noble",
        "nominació",
        "normalitat",
        "notable",
        "notables",
        "NO TRANSLATION",
        "noció",
        "aliment",
        "números",
        "infermera",
        "viver",
        "nodrir",
        "nutritiu",
        "roure",
        "oasi",
        "jurament",
        "obediència",
        "objectiu",
        "obligant",
        "observant",
        "obtinguda",
        "obvi",
        "ocupant",
        "ocupació",
        "ocupar",
        "oferta",
        "oficial",
        "compensació",
        "allunyament",
        "omnisciente",
        "obertura",
        "òpera",
        "oportú",
        "oportunitat",
        "optimisme",
        "optimista",
        "opció",
        "opcional",
        "oracle",
        "oració",
        "orquestra",
        "ordenat",
        "ordenat",
        "ordenació",
        "orgànic",
        "organització",
        "organitzar",
        "organitzat",
        "orgasme",
        "originalitat",
        "adornat",
        "adornat",
        "resultat",
        "outdo",
        "fora",
        "alegre",
        "aclaparadora",
        "propietat",
        "pacífic",
        "coixinet",
        "farcit",
        "paleta",
        "palatable",
        "pal·liatiu",
        "panacea",
        "panache",
        "NO TRANSLATION",
        "pebre vermell",
        "paragon",
        "primordial",
        "perdó",
        "parentiu",
        "parietal",
        "participar",
        "participació",
        "soci",
        "associació",
        "passió",
        "apassionat",
        "passatemps",
        "pastor",
        "pastisseria",
        "pastura",
        "patent",
        "paciència",
        "pacient",
        "patriarcal",
        "mecenes",
        "mecenatge",
        "pagar",
        "pau",
        "pacífica",
        "Pacífic",
        "paó",
        "picar",
        "peculiaritat",
        "pedigree",
        "sense parells",
        "apassionant",
        "percebre",
        "perceptible",
        "perenne",
        "perfecte",
        "perfecció",
        "intèrpret",
        "Perk",
        "permís",
        "perpetuïtat",
        "persistència",
        "persistent",
        "agradable",
        "pertinent",
        "farmacèutica",
        "filantrop",
        "filantropia",
        "filòsof",
        "phoenix",
        "fonètica",
        "metge",
        "física",
        "fisiologia",
        "físic",
        "collir",
        "picnic",
        "pintoresc",
        "pietat",
        "píndola",
        "coixí",
        "pilot",
        "pinacle",
        "pioner",
        "piadoso",
        "pith",
        "pivot",
        "plàcid",
        "planificació",
        "juganer",
        "parc infantil",
        "casa de jocs",
        "agradable",
        "satisfet",
        "plaent",
        "compromís",
        "plenari",
        "abundant",
        "plexus",
        "pruna",
        "plom",
        "felpa",
        "capa",
        "puntualment",
        "policia",
        "policia",
        "polir",
        "polit",
        "educat",
        "cortesia",
        "NO TRANSLATION",
        "piscina",
        "papa",
        "popularitat",
        "popularitzat",
        "població",
        "portàtil",
        "posseir",
        "potable",
        "potència",
        "potent",
        "amb força",
        "pràctica",
        "practicat",
        "pràctica",
        "lloança",
        "elogiat",
        "lloable",
        "pregueu",
        "precaució",
        "precedeix",
        "precedència",
        "preciós",
        "precís",
        "precisió",
        "predilecció",
        "predominant",
        "preeminent",
        "preferir",
        "primer ministre",
        "locals",
        "preparar",
        "preparat",
        "prescient",
        "presència",
        "present",
        "presentable",
        "conservant",
        "preservar",
        "president",
        "prestigi",
        "presto",
        "bonic",
        "prevalgui",
        "prevenció",
        "invalorable",
        "orgull",
        "sacerdot",
        "sacerdoci",
        "sacerdotal",
        "primacia",
        "primària",
        "prime",
        "primer",
        "príncep",
        "princely",
        "princesa",
        "principal",
        "prístina",
        "privilegiada",
        "probitat",
        "procediment",
        "processó",
        "proctor",
        "procurar",
        "prodigiós",
        "prodigi",
        "productor",
        "produint",
        "producció",
        "productiu",
        "productivitat",
        "professió",
        "professional",
        "professor",
        "competència",
        "competent",
        "profus",
        "progrés, progressar",
        "progressió",
        "progressiu",
        "prolífic",
        "prominència",
        "de manera destacada",
        "promesa",
        "prometedor",
        "promoció",
        "Prop",
        "propi",
        "profeta",
        "profilàctic",
        "proposició",
        "perspectiva",
        "prosperar",
        "prosperitat",
        "pròsper",
        "protegir",
        "la protecció",
        "protector",
        "protector",
        "orgullós",
        "demostrar-ho",
        "proverbial",
        "proporcionar",
        "proporcionant",
        "prudència",
        "prudent",
        "salm",
        "públic",
        "tirar",
        "púlpit",
        "puntual",
        "puntualitat",
        "cadell",
        "purament",
        "purificació",
        "purificar",
        "purista",
        "puresa",
        "ronroneo",
        "pintoresc",
        "qualificat",
        "qualificació",
        "cerca",
        "pregunta",
        "rapidesa",
        "quiescent",
        "tranquil",
        "quinina",
        "resplendor",
        "radiant",
        "irradiar",
        "ràdio",
        "aveteu",
        "rapto",
        "racional",
        "lector",
        "fàcilment",
        "preparació",
        "lectura",
        "reafirmar",
        "real",
        "raó",
        "tranquil·litat",
        "tranquil·litzar",
        "descompte",
        "refosa",
        "rebut",
        "rebent",
        "NO TRANSLATION",
        "recíprocament",
        "reclamació",
        "reclinada",
        "reconegut",
        "recomano",
        "reconciliació",
        "reconsideració",
        "reconstruir",
        "reconstrucció",
        "gravadora",
        "recuperació",
        "recuperació",
        "recreació",
        "recreatiu",
        "rectificar",
        "redempció",
        "reparació",
        "refinar",
        "refinament",
        "reforma",
        "reforma",
        "reformador",
        "refrescant",
        "reformar",
        "regal",
        "regent",
        "regularitat",
        "regular",
        "rehabilitar",
        "rehabilitació",
        "reemborsar",
        "reemborsament",
        "reforç",
        "restablir",
        "alegra't",
        "alegria",
        "rejovenir",
        "rejovenit",
        "relaxació",
        "rellevant",
        "fiabilitat",
        "fiable",
        "confiança",
        "alleujament",
        "alleujament",
        "remake",
        "notable",
        "NO TRANSLATION",
        "remei",
        "remissió",
        "remodelació",
        "renaixement",
        "representar",
        "renovació",
        "renovar",
        "renovació",
        "fama",
        "reconegut",
        "reorganitzar",
        "reparació",
        "pagar",
        "penedit",
        "reposar",
        "replet",
        "periodista",
        "repòs",
        "representat",
        "reproductiva",
        "reputable",
        "rescat",
        "reserva",
        "resident",
        "resistent",
        "resistent",
        "resoldre",
        "recursos",
        "respecte",
        "respectabilitat",
        "respectable",
        "respectuós",
        "respectant",
        "respecte",
        "descans",
        "resplendent",
        "responsable",
        "sensible",
        "descans",
        "tranquil",
        "restitució",
        "restaurador",
        "restauració",
        "restricció",
        "represa",
        "retenció",
        "reunió",
        "revel",
        "divertiments",
        "revere",
        "reverència",
        "Reverend",
        "reverie",
        "revisar",
        "revitalització",
        "revolucionari",
        "recompensa",
        "ritme",
        "rítmic",
        "cinta",
        "riquesa",
        "genet",
        "just",
        "legítim",
        "amb raó",
        "madur",
        "madura",
        "pujant",
        "reblat",
        "roadster",
        "robust",
        "rock",
        "barra",
        "rollicking",
        "romanç",
        "romàntic",
        "romanticisme",
        "romp",
        "arrelat",
        "rosat",
        "rota",
        "rutina",
        "reialesa",
        "rúbrica",
        "ruth",
        "segur",
        "salvaguardar",
        "sage",
        "Sant",
        "sant",
        "sou",
        "salient",
        "saludable",
        "saludem",
        "salvació",
        "salve",
        "samurai",
        "santificació",
        "santificar",
        "santuari",
        "sanguina",
        "sanitaris",
        "setinat",
        "de manera satisfactòria",
        "satisfet",
        "guardar",
        "estalvis",
        "assaborir",
        "salat",
        "intel·ligent",
        "erudit",
        "beques",
        "científic",
        "científic",
        "NO TRANSLATION",
        "puntuació",
        "escriba",
        "guió",
        "deliciosos",
        "escultura",
        "mar",
        "segell",
        "sazonat",
        "secretaria",
        "antiguitat",
        "sensacional",
        "sentit",
        "sensibilitat",
        "sensiblement",
        "sensualitat",
        "sensual",
        "sentimental",
        "sentimentalisme",
        "sentinella",
        "serenitat",
        "sermó",
        "sèrum",
        "settlor",
        "sexe",
        "forma",
        "ben format",
        "Compartir",
        "refugi",
        "pastor",
        "brillar",
        "brillant",
        "compres",
        "espatlla",
        "astut",
        "seda",
        "simplificar",
        "sincer",
        "sinceritat",
        "cantar",
        "individualment",
        "senyor",
        "germanor",
        "expert",
        "hàbil",
        "cel",
        "pissarra",
        "pulcre",
        "esvelta",
        "prim",
        "somriure",
        "somrient",
        "ferit",
        "suavitat",
        "snicker",
        "sobrietat",
        "sociable",
        "consol",
        "soldat",
        "sòlid",
        "solidesa",
        "solució",
        "solvència",
        "sonar",
        "sonata",
        "sonnet",
        "sonor",
        "calmar",
        "calmant",
        "NO TRANSLATION",
        "solidesa",
        "sopa",
        "spa",
        "espaiós",
        "spaniel",
        "espurna",
        "especial",
        "NO TRANSLATION",
        "discurs",
        "ràpid",
        "ortografia",
        "espècia",
        "esperit",
        "esperits",
        "esplèndida",
        "esplendor",
        "patrocinador",
        "impecable",
        "cònjuge",
        "avet",
        "estable",
        "staccato",
        "inoxidable",
        "semental",
        "Stalwart",
        "resistència",
        "dempeus",
        "estrella",
        "llum de les estrelles",
        "estreny",
        "senyorial",
        "declaració",
        "estàtua",
        "estat",
        "ferm",
        "ferma",
        "estel·lar",
        "majordom",
        "quietud",
        "botiga",
        "senzill",
        "estratègic",
        "estrateg",
        "força",
        "enfortir",
        "enfortiment",
        "sorprenent",
        "sorprenentment",
        "fortament",
        "estructura",
        "stud",
        "estudiar",
        "resistent",
        "sublimació",
        "substància",
        "substantiu",
        "triomfar",
        "triomfant",
        "èxit",
        "reeixit",
        "succinct",
        "suficiència",
        "sucre",
        "adequat",
        "sensual",
        "sol",
        "assolellat",
        "capvespre",
        "sol",
        "excel·lent",
        "superhumà",
        "superior",
        "superioritat",
        "superman",
        "superestrella",
        "súplica",
        "subministraments",
        "subministrament",
        "recolzat",
        "partidari",
        "suport",
        "suprem",
        "de manera suprema",
        "garantia",
        "suposar",
        "superant",
        "sorpresa",
        "topografia",
        "sobreviure",
        "jura",
        "dolç",
        "amor",
        "carinyo",
        "dolçor",
        "dolços",
        "ràpid",
        "nedar",
        "simbòlic",
        "simètric",
        "simetria",
        "simpàtic",
        "simpatia",
        "simfonia",
        "sincronitzar",
        "sinèrgic",
        "sínode",
        "tacte",
        "conte",
        "talent",
        "talismà",
        "parlar",
        "bronzejat",
        "tasca",
        "de bon gust",
        "saborós",
        "ensenyar",
        "professor",
        "tecnologia",
        "temperança",
        "temperat",
        "Tenable",
        "tenaç",
        "tenacitat",
        "arrendament",
        "arrendatari",
        "tendre",
        "tendresa",
        "agraït",
        "acció de gràcies",
        "teòric",
        "terapèutic",
        "terapèutica",
        "NO TRANSLATION",
        "pura sang",
        "pensatiu",
        "reflexió",
        "bestiar",
        "emoció",
        "emocionant",
        "prosperant",
        "tron",
        "pessigolles",
        "enrajolats",
        "oportuna",
        "oripell",
        "títol",
        "torrades",
        "tolerant",
        "tolerància",
        "superior",
        "duresa",
        "torre",
        "elevat",
        "tradicional",
        "tranquil",
        "tranquilitat",
        "transcendència",
        "transcendental",
        "viatjant",
        "tresor",
        "arbre",
        "tremendament",
        "tendència",
        "de moda",
        "tributari",
        "homenatge",
        "trig",
        "triomf",
        "triomfant",
        "Trofeu",
        "treva",
        "True",
        "confiat",
        "veritat",
        "veracitat",
        "tutela",
        "tutor",
        "bessó",
        "parpellejar",
        "en definitiva",
        "àrbitre",
        "unanimitat",
        "unànime",
        "sense pretensions",
        "imparcial",
        "irrompible",
        "ininterrompudament",
        "sense restriccions",
        "subratllar",
        "comprensió",
        "subscrit",
        "indivisible",
        "imparell",
        "inequívocament",
        "desplegar",
        "unificació",
        "uniformement",
        "no infectat",
        "únic",
        "unison",
        "unitari",
        "units",
        "unitat",
        "universitat",
        "il·limitat",
        "sense pretensions",
        "indiscutible",
        "indubtablement",
        "indiscutit",
        "il·lès",
        "desinteressat",
        "sense igual",
        "incondicional",
        "aixecament",
        "dret",
        "utilitat",
        "usher",
        "habitual",
        "utilitat",
        "utòpic",
        "vacances",
        "vacuna",
        "valent",
        "NO TRANSLATION",
        "valuós",
        "avantguarda",
        "vençut",
        "vellut",
        "vellutat",
        "venerable",
        "veneració",
        "veracitat",
        "verdant",
        "verificació",
        "verificat",
        "en veritat",
        "veritable",
        "vernal",
        "verve",
        "veterà",
        "vicari",
        "vencedor",
        "victoriós",
        "victòria",
        "vigilància",
        "vigilant",
        "vigor",
        "vigorós",
        "vilatà",
        "reivindicat",
        "reivindicació",
        "verge",
        "virginitat",
        "virtut",
        "virtuós",
        "visió",
        "visionari",
        "visita",
        "visitant",
        "vital",
        "vitalitat",
        "vivaz",
        "vívid",
        "vocabulari",
        "voluntari",
        "voluptuós",
        "aval",
        "vot",
        "salaris",
        "garantia",
        "guerrer",
        "guardià",
        "vigilant",
        "vigilant",
        "impermeable",
        "riquesa",
        "resistent a la intempèrie",
        "benvinguda",
        "blanc",
        "blancor",
        "saludable",
        "wicket",
        "àmpliament difós",
        "de bona gana",
        "voluntat",
        "imprevist",
        "guanyador",
        "guanyador",
        "guanys",
        "sense fils",
        "sabia",
        "saviesa",
        "prudent",
        "enginy",
        "suportar",
        "enginy",
        "enginyós",
        "mag",
        "úter",
        "meravellós",
        "meravellosament",
        "meravellós",
        "paraula",
        "treball",
        "adoració",
        "val la pena",
        "digne",
        "wot",
        "escriptor",
        "jove",
        "més jove",
        "joves",
        "zel",
        "zelós",
        "ronc",
    ]
)

_negative = set(
    [
        "abandonar",
        "abandonat",
        "abandó",
        "segrest",
        "aberrant",
        "aberració",
        "abhor",
        "abominable",
        "abjecte",
        "anormal",
        "abolir",
        "abolició",
        "abominable",
        "abominació",
        "avortar",
        "avortament",
        "abortiu",
        "abrasió",
        "cancel·lar",
        "abscés",
        "absència",
        "absent",
        "absent",
        "absentisme",
        "absurd",
        "absurd",
        "abús",
        "abismal",
        "abisme",
        "accident",
        "accidental",
        "maldestre",
        "acusació",
        "acusatiu",
        "acusat",
        "acusador",
        "acusant",
        "dolor",
        "dolor",
        "àcid",
        "accionable",
        "adder",
        "adicció",
        "adipós",
        "adjudicat",
        "admonició",
        "a la deriva",
        "adulterat",
        "adulteri",
        "adversari",
        "advers",
        "adversitat",
        "aflicció",
        "afligit",
        "aflicció",
        "afrontament",
        "té por",
        "conseqüències",
        "regust",
        "agreujat",
        "agreujant",
        "agreujament",
        "agressió",
        "agressiu",
        "agressor",
        "agotar",
        "agitat",
        "agitació",
        "agonitzant",
        "agonia",
        "encallat",
        "ail",
        "malalta",
        "sense sentit",
        "aire",
        "alarma",
        "alarmant",
        "alcoholisme",
        "estranger",
        "alienar",
        "alienat",
        "alienació",
        "pensió alimentària",
        "al · legació",
        "al·leguen",
        "a part",
        "altercació",
        "ambigu",
        "emboscada",
        "amnèsia",
        "amfetamines",
        "anaconda",
        "anal",
        "anarquisme",
        "anarquista",
        "anarquia",
        "Anatema",
        "antic",
        "ràbia",
        "angina",
        "pescant",
        "enutjat",
        "angoixa",
        "animositat",
        "animus",
        "aniquilar",
        "aniquilat",
        "aniquilació",
        "molestar",
        "molèstia",
        "molest",
        "anul·lar",
        "anul·lació",
        "anomalia",
        "anònim",
        "antagonisme",
        "antagonista",
        "antagonista",
        "antrax",
        "anticristo",
        "antipatia",
        "antiquat",
        "antisocial",
        "antitesis",
        "ansietat",
        "ansiós",
        "apache",
        "apàtic",
        "apatia",
        "pugó",
        "horrorós",
        "apendicitis",
        "aprensió",
        "aprensiu",
        "apropiació",
        "arcaic",
        "àrdua",
        "argumentar",
        "argument",
        "argumentatiu",
        "àrid",
        "armaments",
        "expedient",
        "endarreriments",
        "aturar",
        "arrogància",
        "arrogant",
        "arsènic",
        "incendi",
        "artilleria",
        "cendra",
        "avergonyit",
        "cendres",
        "cul",
        "assail",
        "assaltant",
        "assassí",
        "assassinar",
        "assassinat",
        "assalt",
        "asshole",
        "per mal camí",
        "astringent",
        "asil",
        "ateisme",
        "aterosclerosi",
        "atroç",
        "atrocitat",
        "atròfia",
        "atac",
        "atacant",
        "atenuat",
        "atenuació",
        "audàcia",
        "auster",
        "austeritat",
        "autocràtic",
        "autòpsia",
        "allau",
        "avarícia",
        "vengador",
        "aversió",
        "aversió",
        "evitar",
        "evitació",
        "horrible",
        "incomoditat",
        "malament",
        "babble",
        "balbucejar",
        "babuí",
        "cap enrere",
        "cap enrere",
        "reposar",
        "bacteris",
        "NO TRANSLATION",
        "dolent",
        "teixó",
        "malament",
        "maldat",
        "agutzil",
        "esquer",
        "bala",
        "balk",
        "NO TRANSLATION",
        "bandit",
        "bane",
        "bang",
        "banger",
        "desterrar",
        "desterrat",
        "banishment",
        "fallida",
        "fallida",
        "Banshee",
        "barb",
        "bàrbar",
        "bàrbar",
        "barbàrie",
        "escorça",
        "prohibit",
        "estèril",
        "barricada",
        "barrera",
        "sense fonament",
        "bastardo",
        "batedor",
        "maltractat",
        "bateria",
        "batalla",
        "lluitat",
        "camp de batalla",
        "sorollós",
        "bayoneta",
        "portador",
        "bèstia",
        "bestial",
        "batre",
        "caure",
        "pregueu",
        "captaire",
        "mendicitat",
        "behemoth",
        "observat",
        "tardà",
        "menyspreu",
        "bel·ligerant",
        "cinturó",
        "bender",
        "afligit",
        "dol",
        "abandonat",
        "boig",
        "bestial",
        "trair",
        "traïció",
        "beware",
        "desconcertat",
        "parcialitat",
        "tendenciat",
        "discutint",
        "NO TRANSLATION",
        "bigot",
        "granat",
        "bilis",
        "biòpsia",
        "bedoll",
        "lloc de naixement",
        "puta",
        "mossegar",
        "amargament",
        "amargor",
        "estrany",
        "negre",
        "blackjack",
        "xantatge",
        "negritud",
        "culpa",
        "suau",
        "blasfem",
        "blasfèmia",
        "explosió",
        "flagrant",
        "blather",
        "flames",
        "desolador",
        "sagnat",
        "taques",
        "taca",
        "esclatat",
        "cec",
        "encegat",
        "cegament",
        "ceguesa",
        "ampolla",
        "inflat",
        "blob",
        "bloqueig",
        "vessament de sang",
        "sanguinari",
        "sagnant",
        "manchar",
        "bufador",
        "apagada",
        "blues",
        "bluff",
        "error",
        "borrós",
        "borrosa",
        "sonrojar",
        "presumint",
        "bog",
        "fals",
        "bullir",
        "boilerplate",
        "bomba",
        "bombard",
        "bombardeig",
        "bombardejat",
        "esclavitud",
        "bons",
        "boo",
        "booby",
        "beure",
        "NO TRANSLATION",
        "avorriment",
        "avorrit",
        "prestatari",
        "molesteu",
        "molestant",
        "fons",
        "lligat",
        "combat",
        "boví",
        "noi",
        "boicot",
        "presumir",
        "aguardiente",
        "bravat",
        "baralla",
        "descarat",
        "incompliment",
        "desglossament",
        "pont vertebrador",
        "NO TRANSLATION",
        "suborn",
        "suborn",
        "brigada",
        "sofre",
        "truges",
        "broadside",
        "broil",
        "es va trencar",
        "trencat",
        "prostíbul",
        "Moretones",
        "pitjor",
        "brutal",
        "brutalitat",
        "brute",
        "bufet",
        "error",
        "NO TRANSLATION",
        "bulbós",
        "intimidació",
        "bum",
        "bummer",
        "incrèdul",
        "burocràcia",
        "buròcrata",
        "lladre",
        "robatori",
        "enterrament",
        "enterrat",
        "burke",
        "cremat",
        "busted",
        "carnisser",
        "culata",
        "buzzed",
        "cabal",
        "cacofonia",
        "Cad",
        "Cadaver",
        "gàbia",
        "calcular",
        "NO TRANSLATION",
        "trucades",
        "campanyes",
        "cancel · lar",
        "càncer",
        "canker",
        "caníbal",
        "canibalisme",
        "NO TRANSLATION",
        "captiva",
        "captivitat",
        "captor",
        "captura",
        "carcassa",
        "carcinoma",
        "cardiomiopatia",
        "descuit",
        "caricatura",
        "càries",
        "carnisseria",
        "carnal",
        "carnívors",
        "cartell",
        "cas",
        "caixeta",
        "casta",
        "víctima",
        "cataracta",
        "catàstrofe",
        "catèter",
        "precaució",
        "cedeix",
        "cementiri",
        "censurar",
        "censura",
        "cess",
        "cessament",
        "palla",
        "escates",
        "disgust",
        "desafiament",
        "Chaos",
        "caòtic",
        "charade",
        "cobrable",
        "persecució",
        "castigament",
        "xerraire",
        "barat",
        "enganyar",
        "pastís de formatge",
        "xicana",
        "infantil",
        "fred",
        "cloroform",
        "sufocar",
        "còlera",
        "tallar",
        "feina",
        "crònica",
        "cigarret",
        "clamor",
        "xoc",
        "xocant",
        "urpa",
        "claustre",
        "ennuvolat",
        "núvols",
        "grup",
        "torpe",
        "cocaïna",
        "coaccionar",
        "coerció",
        "sarcòfag",
        "fred",
        "fredament",
        "fredor",
        "còlic",
        "col.lapse",
        "col.lisió",
        "col · lusió",
        "coma",
        "comatose",
        "combat",
        "combatent",
        "combativa",
        "comprometre",
        "commoció",
        "comunisme",
        "comunista",
        "competició",
        "queixar-se",
        "queixa",
        "complex",
        "complexitat",
        "complicar",
        "complicat",
        "complicació",
        "compost",
        "compulsió",
        "obligatori",
        "ocultar",
        "amagat",
        "ocultació",
        "presumitiva",
        "presumit",
        "concussió",
        "condemnar",
        "condemna",
        "condescendent",
        "condescension",
        "confessió",
        "confine",
        "confinat",
        "confinament",
        "confiscar",
        "confiscació",
        "conflagració",
        "conflicte",
        "conflictiu",
        "confondre",
        "confosos",
        "confondre",
        "confusió",
        "congestió",
        "conjurant",
        "conquesta",
        "conspirador",
        "conspié",
        "consternació",
        "constipació",
        "restringir",
        "restringit",
        "restricció",
        "contagi",
        "contagiosa",
        "contaminar",
        "contaminat",
        "contaminació",
        "menyspreu",
        "despreciable",
        "despectiu",
        "controvertit",
        "contraban",
        "contractat",
        "contradiu",
        "contradicció",
        "contradictori",
        "al contrari",
        "contrastada",
        "contravenen",
        "contravenció",
        "controvertit",
        "controvèrsia",
        "condemnat",
        "convicció",
        "coop",
        "copiar",
        "copycat",
        "coroner",
        "corporal",
        "cadàver",
        "correcció",
        "corrosió",
        "corrosiu",
        "corrupte",
        "corrompido",
        "corrupció",
        "tos",
        "conseller",
        "corrent",
        "cobert",
        "covard",
        "covardia",
        "covard",
        "crabby",
        "crack",
        "esquerdat",
        "esquerdes",
        "rampa",
        "estret",
        "maneta",
        "cruixent",
        "merda",
        "falla",
        "gatejar",
        "embogit",
        "boig",
        "cruixit",
        "criatura",
        "arrossegar-se",
        "crim",
        "criminal",
        "criminalitat",
        "encongir-se",
        "parapleja",
        "paralitzat",
        "crisi",
        "cruixent",
        "crític",
        "crítica",
        "criticar",
        "lladre",
        "creu",
        "ajupit",
        "creuat",
        "crucifixió",
        "cru",
        "cruel",
        "cruelmente",
        "crueltat",
        "esmicolant",
        "cruixit",
        "croada",
        "aixafat",
        "aixafament",
        "cruixent",
        "plorar",
        "plorant",
        "cripta",
        "corbates",
        "cucut",
        "recolliment",
        "culpabilitat",
        "culpable",
        "culpable",
        "culte",
        "engorrosa",
        "cupping",
        "cur",
        "maledicció",
        "Maleït",
        "maleït",
        "cursiva",
        "tallador",
        "cutthroat",
        "tall",
        "cianur",
        "cicló",
        "quist",
        "citomegalovirus",
        "dabbling",
        "dimoni",
        "daft",
        "daga",
        "dany",
        "danys",
        "maleïda",
        "condemnació",
        "maleït",
        "amortidor",
        "caspa",
        "dandy",
        "perill",
        "perillós",
        "fosc",
        "enfosquit",
        "foscor",
        "va trencar",
        "dastardly",
        "atordit",
        "desactivar",
        "estancament",
        "mortal",
        "sord",
        "mort",
        "debacle",
        "desertatge",
        "escombraries",
        "deute",
        "deutor",
        "decaïment",
        "decadent",
        "mort",
        "engany",
        "enganyós",
        "enganyar",
        "enganyat",
        "enganyant",
        "engany",
        "enganyós",
        "declinació",
        "disminució",
        "disminuint",
        "descomposició",
        "disminuir",
        "disminució",
        "decrepit",
        "decry",
        "deduir",
        "difamació",
        "difamatori",
        "per defecte",
        "derrota",
        "vençut",
        "defecte",
        "NO TRANSLATION",
        "defectuós",
        "indefens",
        "ajornament",
        "desafiament",
        "desafiant",
        "deficiència",
        "dèficit",
        "desinflar",
        "deflació",
        "deformar",
        "deformat",
        "deformitat",
        "defraudar",
        "desaparegut",
        "desafiar",
        "degeneració",
        "degenerar",
        "degradació",
        "degradar",
        "degradant",
        "retard",
        "retardat",
        "perjudicial",
        "eliminació",
        "delinqüència",
        "delinqüent",
        "delirant",
        "deliri",
        "diluvi",
        "engany",
        "delirant",
        "demanda",
        "exigent",
        "dementat",
        "demència",
        "desaparició",
        "demolir",
        "demolició",
        "dimoni",
        "demoníac",
        "desmoralitzat",
        "negació",
        "negat",
        "denunciar",
        "denúncia",
        "negar",
        "negant",
        "sortit",
        "sortida",
        "dependència",
        "dependència",
        "deplorable",
        "deplorar",
        "deportar",
        "deportació",
        "depravat",
        "depravació",
        "depreciar",
        "depreciat",
        "depreciació",
        "deprimir",
        "deprimit",
        "depriment",
        "depressió",
        "depressiu",
        "privació",
        "deranged",
        "abandonat",
        "burla",
        "excepció",
        "derogatori",
        "profanació",
        "desert",
        "abandonat",
        "desertió",
        "desistir",
        "desolació",
        "desesperació",
        "desesperació",
        "desesperat",
        "despreciable",
        "NO TRANSLATION",
        "despòtic",
        "despotisme",
        "indigent",
        "destruït",
        "destructor",
        "destruint",
        "destrucció",
        "destructiu",
        "despreniment",
        "detenir",
        "detingut",
        "detenció",
        "deteriorar",
        "deteriorat",
        "deteriorament",
        "detest",
        "detonar",
        "detriment",
        "detriment",
        "perjudicial",
        "detritus",
        "devastar",
        "devastador",
        "devastació",
        "diable",
        "diabòlic",
        "desviat",
        "devolució",
        "devorar",
        "diabòlic",
        "diagnòstic",
        "diatribe",
        "dictador",
        "dictatorial",
        "dictadura",
        "NO TRANSLATION",
        "dificultats",
        "dificultat",
        "digress",
        "en ruïnes",
        "diluir",
        "disminuir",
        "disminuït",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "brutícia",
        "brut",
        "discapacitat",
        "desactivar",
        "desactivat",
        "descontent",
        "discrepar",
        "en desacord",
        "desacord",
        "inhabilitat",
        "decebre",
        "decebut",
        "decebedor",
        "decepció",
        "desaprovació",
        "rebutjar",
        "rebutjat",
        "rebutjant",
        "desastre",
        "desastrós",
        "no creure",
        "descarta",
        "alta",
        "disciplina",
        "renunciar",
        "decoloració",
        "descolorit",
        "incomoditat",
        "desconnectar",
        "desconnectat",
        "desconnexió",
        "descontentament",
        "interrompre",
        "discontinuïtat",
        "discòrdia",
        "descoratjar",
        "desànim",
        "descrèdit",
        "discriminar",
        "discriminant",
        "discriminació",
        "menyspreu",
        "malaltia",
        "malalt",
        "desencarnat",
        "desconnexió",
        "desfigurada",
        "desgràcia",
        "NO TRANSLATION",
        "vergonyós",
        "descontent",
        "disgustat",
        "desagradable",
        "descoratjat",
        "descoratjador",
        "deshonest",
        "deshonestedat",
        "deshonor",
        "desil·lusió",
        "desinformació",
        "desconcertant",
        "es desintegren",
        "desintegració",
        "desinteressat",
        "No m'agrada",
        "no li agradava",
        "dislocat",
        "trist",
        "consternació",
        "desmembrament",
        "acomiadament",
        "desobediència",
        "desobedient",
        "desobeir",
        "trastorn",
        "desordenat",
        "desorganitzat",
        "disparage",
        "despectiva",
        "disparitat",
        "desapassionat",
        "disipar",
        "dispersió",
        "desplaçar",
        "descontent",
        "descontentament",
        "disposició",
        "desposseït",
        "disputa",
        "inhabilitació",
        "descalificada",
        "descalificar",
        "ignorar",
        "ignorat",
        "indescriptible",
        "falta de respecte",
        "irrespectuosa",
        "interrupció",
        "insatisfacció",
        "dissensió",
        "dissident",
        "disservice",
        "dissident",
        "dissolució",
        "dissonància",
        "distès",
        "desagradable",
        "distorsionat",
        "distorsió",
        "distreure",
        "distret",
        "distreure",
        "distracció",
        "distraído",
        "angoixa",
        "afligit",
        "molestant",
        "desconfiança",
        "pertorbació",
        "pertorbat",
        "desús",
        "en desús",
        "divergent",
        "desposseït",
        "desinversió",
        "divorci",
        "mareig",
        "mareig",
        "atracat",
        "NO TRANSLATION",
        "doldrums",
        "Dole",
        "NO TRANSLATION",
        "dominant",
        "dominació",
        "ruc",
        "doodle",
        "destrucció",
        "condemnat",
        "dia del final del judici",
        "dubte",
        "dubtós",
        "dubtant",
        "douche",
        "dour",
        "caiguda",
        "drab",
        "drenatge",
        "inconvenient",
        "temor",
        "terrible",
        "terriblement",
        "trist",
        "beure",
        "drivel",
        "avioneta",
        "caiguda",
        "sequera",
        "ofegar",
        "somnolència",
        "perruqueria",
        "borratxo",
        "embriaguesa",
        "dubtós",
        "avorrit",
        "mut",
        "maniquí",
        "abocadors",
        "dun",
        "masmorra",
        "dupe",
        "duplicitat",
        "molestia",
        "pols",
        "enana",
        "morint",
        "disenteria",
        "terratrèmol",
        "escolta",
        "edició",
        "efeminat",
        "egoista",
        "exagerat",
        "expulsar",
        "expulsió",
        "eliminació",
        "evasiu",
        "emaciat",
        "NO TRANSLATION",
        "avergonyir",
        "embarazoso",
        "vergonya",
        "malversació",
        "embolia",
        "embruixat",
        "emergència",
        "enclavament",
        "invasió",
        "gravamen",
        "posa en perill",
        "en perill d'extinció",
        "endèmic",
        "enemic",
        "compliment",
        "enigmàtic",
        "enemistat",
        "esclau",
        "esclau",
        "esclavitud",
        "Enredat",
        "entanglement",
        "entranyes",
        "enveja",
        "epidèmia",
        "epilèpsia",
        "eradicar",
        "eradicació",
        "esborrar",
        "erosió",
        "errar",
        "errante",
        "erràtic",
        "erratum",
        "errònia",
        "error",
        "esclatar",
        "erupció",
        "escalada",
        "eviteu",
        "espionatge",
        "allunyat",
        "eutanàsia",
        "evacuar",
        "evacuació",
        "evadir",
        "evasió",
        "desallotjar",
        "desallotjament",
        "dolent",
        "empitjorar",
        "exacerbació",
        "exigent",
        "exagerar",
        "exagerat",
        "examen",
        "exasperació",
        "excavació",
        "excés",
        "impostos especials",
        "exclosos",
        "Excloent",
        "exclusió",
        "excrements",
        "excruciant",
        "excusa",
        "execució",
        "botxí",
        "escapament",
        "esgotat",
        "esgotament",
        "NO TRANSLATION",
        "exili",
        "exorcisme",
        "expatriats",
        "expulsar",
        "despeses",
        "despeses",
        "caducar",
        "vençut",
        "expletiu",
        "explotar",
        "explosió",
        "explosiu",
        "exposat",
        "expropiació",
        "expulsió",
        "exterminar",
        "extermini",
        "extingit",
        "extingir",
        "extrajudicial",
        "extremitat",
        "fabricar",
        "fabricació",
        "esvaeix",
        "femta",
        "fallant",
        "fracàs",
        "desmais",
        "sense fe",
        "fals",
        "caure",
        "fallida",
        "fal·làcia",
        "fallible",
        "caient",
        "guaret",
        "falsedat",
        "falsament",
        "falsificació",
        "falsificar",
        "falsedat",
        "falter",
        "fam",
        "fanàtic",
        "farsa",
        "bromista",
        "fasting",
        "greix",
        "mortal",
        "mortalitat",
        "destí",
        "fatiga",
        "fatigat",
        "greix",
        "falta",
        "defectuós",
        "cervatell",
        "por",
        "temorós",
        "amb por",
        "tement",
        "febril",
        "fecal",
        "excrements",
        "tarifa",
        "feble",
        "fingit",
        "va caure",
        "felon",
        "delicte greu",
        "Ferment",
        "feroç",
        "ferocitat",
        "disputa",
        "feudal",
        "feudalisme",
        "febril",
        "fiasco",
        "FIB",
        "inconstante",
        "fictici",
        "fiend",
        "ferotge",
        "lluitar",
        "lluitant",
        "filibuster",
        "brutícia",
        "brut",
        "armes de foc",
        "encaixa",
        "flabby",
        "flàccid",
        "marcat",
        "flagrant",
        "escates",
        "solapa",
        "flatulència",
        "ostentar",
        "defecte",
        "puça",
        "NO TRANSLATION",
        "vellesa",
        "carnosa",
        "flinch",
        "flog",
        "flop",
        "llistó",
        "grip",
        "fluctuació",
        "enemic",
        "frustrat",
        "bogeria",
        "ximple",
        "neci",
        "insensatesa",
        "farratge",
        "incursió",
        "prohibir",
        "prohibir",
        "força",
        "obligat",
        "forçat",
        "foreboding",
        "excloent",
        "abandonat",
        "estranger",
        "estranger",
        "avís previ",
        "perdut",
        "perdut",
        "decomís",
        "falsificació",
        "oblida't",
        "oblidat",
        "allunyat",
        "sense formes",
        "fornicació",
        "abandonar",
        "abandonat",
        "falta",
        "fractura",
        "fràgil",
        "fragilitat",
        "frenètic",
        "frau",
        "fraudulent",
        "ple",
        "fre",
        "desgastat",
        "freakish",
        "congelació",
        "frenètic",
        "frenètic",
        "frenesí",
        "estret",
        "espanto",
        "espantar",
        "espantat",
        "espantós",
        "frigida",
        "frívol",
        "congelació",
        "escuma",
        "arrufat el nas",
        "arrufat el nas",
        "infructuós",
        "frustrar",
        "frustrat",
        "frustració",
        "fudge",
        "fugitiu",
        "fumble",
        "fum",
        "fumant",
        "fong",
        "funk",
        "furiós",
        "furor",
        "fúria",
        "escàndol",
        "llepafils",
        "fútil",
        "futilitat",
        "gaby",
        "mordassa",
        "gall",
        "forca",
        "jugar",
        "jugador",
        "jocs d'atzar",
        "colla",
        "gaol",
        "buit",
        "escombraries",
        "garish",
        "adornar",
        "gash",
        "apagant",
        "NO TRANSLATION",
        "amargat",
        "gent",
        "geriàtric",
        "horrible",
        "gueto",
        "fantasmal",
        "gibberish",
        "glacial",
        "resplendor",
        "boig",
        "glib",
        "tristesa",
        "sombrío",
        "glum",
        "glut",
        "glutoneria",
        "gnome",
        "goblin",
        "godless",
        "gonorrea",
        "goo",
        "gore",
        "congost",
        "goril·la",
        "gory",
        "xafarderies",
        "gouge",
        "gota",
        "govern",
        "agafar",
        "agafant",
        "reixeta",
        "ratllat",
        "reixeta",
        "sepultura",
        "avidesa",
        "cobdiciós",
        "magrana",
        "pena",
        "queixa",
        "dolent",
        "dolent",
        "tèrmic",
        "mugre",
        "grimy",
        "mòlta",
        "grisamente",
        "grisós",
        "gemegar",
        "NO TRANSLATION",
        "brut",
        "grotesc",
        "connectat a terra",
        "sense fonament",
        "créixer",
        "rosegant",
        "rencor",
        "de mala gana",
        "horrible",
        "horrible",
        "callar",
        "grumpy",
        "guerrilla",
        "guile",
        "guillotina",
        "culpa",
        "culpable",
        "disfressa",
        "gavina",
        "engreixable",
        "arma de foc",
        "gush",
        "guzzling",
        "gitana",
        "Hag",
        "enganyat",
        "pelut",
        "a mig camí",
        "al·lucinació",
        "halter",
        "detenció",
        "obstaculitzar",
        "hamstring",
        "handicap",
        "penjant",
        "penjat",
        "assetjar",
        "presoner",
        "endurit",
        "duresa",
        "dificultats",
        "ramera",
        "danyar",
        "perjudicial",
        "horrible",
        "harry",
        "duresa",
        "hash",
        "haixix",
        "precipitada",
        "odi",
        "odiós",
        "odiar",
        "odi",
        "altivesa",
        "perseguir",
        "embruixat",
        "estralls",
        "perill",
        "perillós",
        "boirina",
        "mal de cap",
        "boig",
        "audició",
        "escoltar",
        "hearse",
        "dolors",
        "ardor d'estómac",
        "sense cor",
        "pagans",
        "fortament",
        "taló",
        "augmentar",
        "horrible",
        "infern",
        "infernal",
        "indefens",
        "impotència",
        "hemorràgia",
        "hemorroides",
        "herejía",
        "heretge",
        "hermafrodita",
        "heroïna",
        "herpes",
        "herpesvirus",
        "vacil · lació",
        "amagat",
        "horrible",
        "dificultant",
        "impediment",
        "hippie",
        "silenci",
        "xiuxiuejant",
        "colpejar",
        "fins ara",
        "rusc",
        "ronca",
        "hoary",
        "engany",
        "hobo",
        "porc",
        "buit",
        "holocaust",
        "sense llar",
        "nostàlgic",
        "homicidi",
        "homicidi",
        "homosexualitat",
        "caputxa",
        "enganxat",
        "Hoot",
        "sense esperança",
        "desesperança",
        "horda",
        "horrible",
        "horriblement",
        "horrible",
        "horrible",
        "horroritzat",
        "horrorós",
        "horror",
        "horrors",
        "ostatge",
        "hostil",
        "hostilitats",
        "hostilitat",
        "aullar",
        "huff",
        "humbug",
        "humiliar",
        "humiliant",
        "humiliació",
        "cop",
        "famolenc",
        "caçador",
        "cacera",
        "huracà",
        "es va apressar",
        "ferit",
        "perjudicial",
        "fer mal",
        "empujador",
        "hydra",
        "hydrocephalus",
        "bombo",
        "hipèrbola",
        "hipocresia",
        "hipòcrita",
        "hipòcrita",
        "histeria",
        "histèrica",
        "idiotes",
        "idiota",
        "idiota",
        "idler",
        "idolatria",
        "ignorància",
        "ignorant",
        "ignorar",
        "malalt",
        "il·legal",
        "il·legalitat",
        "il·legible",
        "il·legítim",
        "il·lícit",
        "analfabeta",
        "malaltia",
        "il·lògic",
        "il·lusió",
        "imitat",
        "imitació",
        "immadur",
        "immaduresa",
        "immoral",
        "immoralitat",
        "perjudicar",
        "deteriorament",
        "intransitable",
        "impaciència",
        "impacient",
        "impeach",
        "impeachment",
        "impedir",
        "imperfecció",
        "imperfecta",
        "suplantar",
        "suplantació",
        "implacable",
        "implicar",
        "impolite",
        "imposició",
        "impossible",
        "impotència",
        "impotent",
        "embargar",
        "impracticable",
        "empresonar",
        "empresonat",
        "empresonament",
        "impropriety",
        "imprudent",
        "impur",
        "impuresa",
        "imputació",
        "incapacitat",
        "inaccessible",
        "inexacte",
        "inacció",
        "inactivitat",
        "insuficiència",
        "inadequat",
        "inadmissible",
        "inane",
        "inaplicable",
        "inadequat",
        "desatenció",
        "inaudible",
        "incalculable",
        "incapacitat",
        "encarceració",
        "en cas de",
        "incendiari",
        "encens",
        "incessant",
        "incest",
        "incestuós",
        "incineració",
        "incitar",
        "inclement",
        "incoherent",
        "incompatible",
        "incompetència",
        "incompetent",
        "incomplet",
        "incomprensible",
        "incongruent",
        "inconsecuente",
        "desconsiderat",
        "inconsistència",
        "inconvenient",
        "incorrecte",
        "incrèdul",
        "incriminació",
        "incubus",
        "incórrer",
        "incurable",
        "incursió",
        "indecent",
        "indecisió",
        "indecís",
        "indefensible",
        "indemnitzar",
        "indenture",
        "indeterminat",
        "acusació",
        "acusació",
        "indiferència",
        "indigent",
        "indignat",
        "indignació",
        "indistint",
        "adoctrinament",
        "indolent",
        "ineficaç",
        "ineficaç",
        "ineficiència",
        "ineficient",
        "inepto",
        "ineptitud",
        "desigualtat",
        "inequitativa",
        "inert",
        "inexcusable",
        "NO TRANSLATION",
        "sense experiència",
        "inexplicable",
        "infame",
        "infamia",
        "infanticidi",
        "infantil",
        "infart",
        "infectar",
        "infecció",
        "infeccioses",
        "inferior",
        "inferioritat",
        "inferno",
        "infertilitat",
        "infestació",
        "infidel",
        "infidelitat",
        "malalt",
        "malaltia",
        "inflamació",
        "inflat",
        "inflació",
        "infligir",
        "infliction",
        "grip",
        "informador",
        "infracció",
        "amb poca freqüència",
        "infracció",
        "inhibir",
        "inhòspit",
        "inhumans",
        "inhumanitat",
        "inimical",
        "iniquitat",
        "ordre judicial",
        "ferir",
        "lesionat",
        "injuriosa",
        "ferida",
        "injustícia",
        "pres",
        "inoperant",
        "boig",
        "la bogeria",
        "insegur",
        "inseguretat",
        "insidiosa",
        "insignificància",
        "insignificant",
        "insípid",
        "insolent",
        "insolvència",
        "insolvent",
        "inestabilitat",
        "instigar",
        "instigació",
        "insuficiència",
        "insuficient",
        "insuficient",
        "insult",
        "insultant",
        "insurgent",
        "insuperable",
        "insurrecció",
        "entre altres",
        "interdicció",
        "interferència",
        "enterrament",
        "interrompre",
        "interromput",
        "intestado",
        "intimidar",
        "intimidació",
        "intolerable",
        "intolerància",
        "intolerant",
        "intoxicat",
        "intractable",
        "intriga",
        "intrús",
        "intrusió",
        "intrusiu",
        "envair",
        "invasor",
        "invalidar",
        "invalidació",
        "invalidesa",
        "invasió",
        "involuntari",
        "involució",
        "irate",
        "NO TRANSLATION",
        "planxes",
        "irracional",
        "irracionalitat",
        "irreconciliable",
        "irregular",
        "irregularitat",
        "irrelevant",
        "irreparable",
        "irresponsable",
        "irreverent",
        "irrevocable",
        "irritabilitat",
        "irritable",
        "irritant",
        "irritació",
        "aïllat",
        "aïllament",
        "jabber",
        "presó",
        "argot",
        "nerviós",
        "icterícia",
        "gelós",
        "gelosia",
        "compromès",
        "perill",
        "john",
        "broma",
        "NO TRANSLATION",
        "confús",
        "escombraries",
        "junta",
        "juvenil",
        "kern",
        "patada",
        "segrestar",
        "matar",
        "matant",
        "cometa",
        "genial",
        "nusos",
        "treballat",
        "laboriosa",
        "laberint",
        "falta",
        "mancat",
        "absurd",
        "carregat",
        "retard",
        "retardat",
        "guarida",
        "lamentar",
        "deslizamiento de terra",
        "lànguid",
        "languidece",
        "languideciendo",
        "lapse",
        "larceny",
        "pestanya",
        "tard",
        "retard",
        "latent",
        "latrines",
        "risible",
        "lava",
        "angoixa",
        "demanda",
        "advocat",
        "laxa",
        "laxant",
        "mandrós",
        "fugida",
        "fuites",
        "fugaç",
        "sortir",
        "sangui",
        "flors",
        "NO TRANSLATION",
        "llimona",
        "lepra",
        "lesbianes",
        "disminuir",
        "menor",
        "letal",
        "letargia",
        "leucèmia",
        "imposar",
        "lewd",
        "enllaç",
        "mentir",
        "libel",
        "llepar",
        "mentir",
        "sense vida",
        "limitat",
        "boig",
        "Lint",
        "licor",
        "sense sentit",
        "litigant",
        "litigar",
        "litigi",
        "litigiosos",
        "escombraries",
        "líquid",
        "pa",
        "loafer",
        "NO TRANSLATION",
        "no ho dubtis",
        "aversió",
        "desconcertant",
        "lobbista",
        "NO TRANSLATION",
        "llagosta",
        "elevat",
        "solitud",
        "solitari",
        "solitari",
        "loo",
        "teler",
        "loon",
        "loony",
        "botí",
        "perdre",
        "perdent",
        "pèrdua",
        "perdut",
        "sonoritat",
        "saló",
        "piojo",
        "més baix",
        "baixant",
        "el més baix",
        "terres baixes",
        "humil",
        "ridícul",
        "tornejat",
        "mòdul",
        "boig",
        "ludeig",
        "lunàtic",
        "empeny",
        "atraure",
        "escabrosos",
        "escampa",
        "a l'aguait",
        "exuberant",
        "lujuria",
        "alegre",
        "estirat",
        "linxar",
        "maça",
        "boig",
        "boig",
        "boig",
        "bogeria",
        "màfia",
        "maggot",
        "improvisat",
        "malaltia",
        "malestar",
        "malària",
        "malevolent",
        "malversació",
        "malformació",
        "malícia",
        "maliciós",
        "maligne",
        "malignitat",
        "maligne",
        "negligència",
        "mandamus",
        "NO TRANSLATION",
        "mangle",
        "mania",
        "maníac",
        "maníacs",
        "manipular",
        "manipulació",
        "homicidi",
        "fems",
        "mar",
        "marge",
        "granat",
        "martingale",
        "màrtir",
        "martiri",
        "masoquisme",
        "massacre",
        "materialisme",
        "materialista",
        "meandre",
        "sense sentit",
        "xarampió",
        "entrometerse",
        "mediocre",
        "mediocritat",
        "malenconiós",
        "malenconia",
        "melee",
        "melodrama",
        "fuga",
        "amenaça",
        "amenaçador",
        "Menial",
        "mercenari",
        "sense pietat",
        "desordre",
        "desordenat",
        "metàstasi",
        "metanol",
        "mildiu",
        "milícies",
        "mimetisme",
        "minimitzar",
        "mínim",
        "minoria",
        "NO TRANSLATION",
        "mal comportamiento",
        "avortament involuntari",
        "travesura",
        "entremaliat",
        "equívoca",
        "mala conducta",
        "miserable",
        "miserablement",
        "misèria",
        "desgràcia",
        "equivocada",
        "contratemps",
        "mala interpretació",
        "enganyar",
        "enganyós",
        "mala administració",
        "incompatibilitat",
        "nom incorrecte",
        "esborrar",
        "fora de lloc",
        "tergiversar",
        "tergiversació",
        "tergiversat",
        "falta",
        "equivocació incorrecta",
        "errada",
        "equivocat",
        "amant",
        "NO TRANSLATION",
        "malentendre",
        "malentès",
        "mal ús",
        "àcar",
        "mob",
        "burla",
        "burlant",
        "molestation",
        "monocrom",
        "monopolista",
        "monsó",
        "monstre",
        "monstruositat",
        "canviant d'humor",
        "discutible",
        "morbid",
        "morbiditat",
        "morgue",
        "moribund",
        "Moron",
        "Moronic",
        "morsel",
        "mortal",
        "mortalitat",
        "mortificació",
        "mortuari",
        "mosquit",
        "plorar",
        "lamentable",
        "dol",
        "muck",
        "fang",
        "muddle",
        "muddled",
        "fangós",
        "muff",
        "mula",
        "mare",
        "mumble",
        "paparres",
        "assassinat",
        "assassí",
        "assassí",
        "tèrbol",
        "NO TRANSLATION",
        "mossegat",
        "mutant",
        "mutilat",
        "mutilació",
        "mutiny",
        "NO TRANSLATION",
        "musell",
        "miopia",
        "nab",
        "nadir",
        "NO TRANSLATION",
        "ingenu",
        "sense nom",
        "bolquers",
        "estupefaents",
        "desagradable",
        "travieso",
        "nàusees",
        "nàusees",
        "NO TRANSLATION",
        "necessari",
        "necessitats",
        "nefarious",
        "negació",
        "negatiu",
        "negligència",
        "descuidat",
        "descuidant",
        "negligència",
        "negligent",
        "NO TRANSLATION",
        "negre",
        "nepotisme",
        "nerviós",
        "no més",
        "ortiga",
        "neuràlgia",
        "neurosi",
        "neuròtic",
        "nicotina",
        "nigger",
        "malson",
        "nihilisme",
        "soroll",
        "sorollós",
        "NO TRANSLATION",
        "sense sentit",
        "sense sentit",
        "corda",
        "la resurrecció",
        "nocius",
        "molèstia",
        "NO TRANSLATION",
        "anul·lar",
        "entumit",
        "entumiment",
        "NO TRANSLATION",
        "oaf",
        "obesitat",
        "obesitat",
        "obi",
        "obit",
        "obituari",
        "objecció",
        "objetable",
        "obligar",
        "obligant",
        "esborrar",
        "esborrat",
        "obliteració",
        "oblit",
        "desagradable",
        "obscè",
        "obscenitat",
        "obscuritat",
        "obstacle",
        "obstinat",
        "obstruir",
        "obstrucció",
        "obstructiva",
        "obtús",
        "ocult",
        "estranyesa",
        "odiós",
        "olor",
        "ofendre",
        "ofès",
        "delinqüent",
        "delicte",
        "ofensiu",
        "fora de casa",
        "offing",
        "ogre",
        "olfactiu",
        "oligarquia",
        "presagi",
        "ominós",
        "ometre",
        "onerós",
        "onus",
        "ooze",
        "opac",
        "operatic",
        "opiaci",
        "opinionated",
        "opi",
        "oponent",
        "oposar-se a",
        "oposat",
        "oposició",
        "opressió",
        "opressió",
        "opressiu",
        "opressor",
        "Orc",
        "calvície",
        "artilleria",
        "orfe",
        "ostensiblement",
        "expulsió",
        "marginat",
        "crit",
        "outhouse",
        "extravagant",
        "prohibit",
        "indignació",
        "ovació",
        "superació",
        "sobrecàrrega",
        "ennuvolat",
        "exagerar",
        "sobredosi",
        "endarrerit",
        "sobreestimat",
        "desbordament",
        "cobert",
        "sobrecàrrega",
        "en excés",
        "poder domèstic",
        "Overpowering",
        "molt car",
        "supervisió",
        "derrocar",
        "bolcat",
        "aclaparat",
        "aclaparat",
        "degut",
        "oxidació",
        "dolor",
        "dolorós",
        "dolorós",
        "dolorosament",
        "dolors",
        "paràlisi",
        "pandèmia",
        "NO TRANSLATION",
        "pànic",
        "paràlisi",
        "paralitzat",
        "paranoia",
        "paràsit",
        "NO TRANSLATION",
        "lloro",
        "parsimoniós",
        "partidista",
        "NO TRANSLATION",
        "passiu",
        "passivitat",
        "pegat",
        "patètic",
        "patronització",
        "NO TRANSLATION",
        "escassetat",
        "captaire",
        "peó",
        "retrocés",
        "pagament",
        "peculiaritats",
        "vianant",
        "penal",
        "penalització",
        "penetració",
        "penitenciari",
        "perdició",
        "perill",
        "perillós",
        "morir",
        "perible",
        "va perir",
        "perir",
        "perjuri",
        "perniciosa",
        "autor",
        "perpetuació",
        "perplex",
        "perplexitat",
        "perseguir",
        "persecució",
        "pertorbació",
        "tos ferina",
        "pervers",
        "perversió",
        "pervertit",
        "pervertit",
        "pessimisme",
        "pessimista",
        "plaga",
        "pesta",
        "mascota",
        "petit",
        "fantasma",
        "catarro",
        "fals",
        "piquet",
        "piquet",
        "escabetx",
        "porc",
        "colom",
        "piles",
        "pillatge",
        "xulo",
        "pimple",
        "pi",
        "pinyó",
        "pique",
        "pirateria",
        "pirata",
        "pistola",
        "trampa",
        "plagi",
        "plaga",
        "demandant",
        "platejat",
        "jugador",
        "súplica",
        "malament",
        "plodding",
        "plummet",
        "saqueig",
        "submergir-se",
        "pneumònia",
        "caça furtiva",
        "sense sentit",
        "verí",
        "enverinat",
        "intoxicació",
        "verinós",
        "picar",
        "polèmica",
        "polio",
        "contamina",
        "Pol · lució",
        "poligàmia",
        "pompa",
        "pomposo",
        "pesat",
        "malament",
        "pop",
        "porc espín",
        "porno",
        "porno",
        "pornogràfic",
        "pornografia",
        "poseu",
        "posseït",
        "possessió",
        "pòstum",
        "ajornament",
        "lliura",
        "pobresa",
        "impotent",
        "broma",
        "precari",
        "recinte",
        "depredador",
        "predicament",
        "embaràs",
        "prejudici",
        "prejudicis",
        "prejudicial",
        "premeditada",
        "pressió",
        "presumptuós",
        "fingir",
        "fingit",
        "fingint",
        "pretensió",
        "pretensions",
        "preventiva",
        "presa",
        "picar",
        "espinós",
        "presó",
        "pres",
        "privy",
        "problema",
        "retardar",
        "dilacion",
        "profà",
        "profanitat",
        "profusió",
        "prohibit",
        "prohibició",
        "perllongar",
        "promiscu",
        "propaganda",
        "perseguir",
        "enjudiciament",
        "prostituta",
        "prostitució",
        "provocació",
        "provocant",
        "picar",
        "curiositat",
        "psicosi",
        "publicista",
        "puffy",
        "cop de puny",
        "picant",
        "castigar",
        "castigat",
        "castigar",
        "càstig",
        "punitiu",
        "purgatori",
        "purga",
        "pus",
        "chack",
        "quagmire",
        "codony",
        "dilema",
        "baralla",
        "esborra",
        "calmar",
        "qüestionable",
        "Quicksilver",
        "deixar de fumar",
        "calfred",
        "tremolor",
        "prova",
        "lladre",
        "rabiós",
        "ràbia",
        "prestatge",
        "raqueta",
        "radiació",
        "radioactius",
        "radó",
        "ràbia",
        "furiós",
        "draps",
        "incursió",
        "ferrocarril",
        "Ram",
        "passejant",
        "enrenou",
        "ranci",
        "Rescat",
        "violació",
        "rapaces",
        "malvat",
        "erupció cutània",
        "rat",
        "qualificació",
        "estrident",
        "rabiós",
        "fastigós",
        "reaccionari",
        "darrere",
        "rebel",
        "reprensió",
        "Rebut",
        "recalcitrant",
        "recessió",
        "reincidència",
        "imprudent",
        "imprudència",
        "redundant",
        "reflux",
        "refractari",
        "negativa",
        "refuse",
        "es va negar",
        "tornada",
        "regressió",
        "lamenta",
        "lamentable",
        "lamentat",
        "lamentant",
        "regulador",
        "regna",
        "rebutjar",
        "rebutjada",
        "rebuig",
        "rebutja",
        "recidiva",
        "relegació",
        "renunciar",
        "reticent",
        "reclam",
        "remei",
        "remiss",
        "remordiment",
        "eliminació",
        "eliminar",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "renegat",
        "renunciar",
        "renúncia",
        "NO TRANSLATION",
        "repel·lent",
        "repel·lint",
        "reprimir",
        "repressió",
        "reprimenda",
        "reimpressió",
        "represàlia",
        "retret",
        "República",
        "repudi",
        "repulsió",
        "rescindir",
        "rescisió",
        "ressentir",
        "ressentit",
        "ressentiment",
        "resignar",
        "renúncia",
        "resignat",
        "resistir",
        "resistència",
        "resistent",
        "resistint",
        "refrenar",
        "restringir",
        "restricció",
        "restrictiu",
        "prendre represàlies",
        "represàlia",
        "represàlia",
        "Retard",
        "retard",
        "reticent",
        "retort",
        "retractar",
        "retracció",
        "retrocés",
        "retribució",
        "retrògrad",
        "venjança",
        "reversió",
        "revocació",
        "revocar",
        "revolta",
        "revoltant",
        "revòlver",
        "repulsió",
        "reumatisme",
        "fastuositat",
        "plagat",
        "ridícul",
        "ridícul",
        "abundant",
        "rifle",
        "escletxa",
        "rígid",
        "rigidesa",
        "rigor",
        "rigorós",
        "timbre",
        "motí",
        "molest",
        "risc",
        "arriscat",
        "rivalitat",
        "robar",
        "lladre",
        "robatori",
        "Deshonor",
        "rook",
        "podridura",
        "podrida",
        "rugositat",
        "NO TRANSLATION",
        "fila",
        "sorollós",
        "escombraries",
        "runes",
        "rue",
        "ruffle",
        "accidentat",
        "ruïna",
        "arruïnat",
        "ruïnós",
        "rumor",
        "fugitiu",
        "ruptura",
        "NO TRANSLATION",
        "òxid",
        "rovellat",
        "cruel",
        "NO TRANSLATION",
        "sabotatge",
        "sacrificis",
        "per desgràcia",
        "tristesa",
        "caure",
        "saba",
        "sarcasme",
        "sarcoma",
        "sardònics",
        "satànic",
        "saturat",
        "salvatge",
        "salvatgisme",
        "costra",
        "bastida",
        "bisturí",
        "escamós",
        "escàndol",
        "escandalós",
        "escassa",
        "chivo expiatorio",
        "cicatriu",
        "escàs",
        "amb prou feines",
        "escassetat",
        "espantar",
        "scavenger",
        "esquema",
        "cisma",
        "esquizofrènia",
        "ciàtica",
        "burlar-se",
        "escolta",
        "rega",
        "escumejant",
        "menyspreu",
        "escorpí",
        "escocesa",
        "canalla",
        "plaga",
        "lluitar",
        "scrapie",
        "crit",
        "cridant",
        "calfar",
        "cargolat",
        "scrimmage",
        "fregar",
        "escrutini",
        "escrutini",
        "escòria",
        "sear",
        "secessió",
        "aïllat",
        "NO TRANSLATION",
        "secreció",
        "secretiva",
        "sectari",
        "sedició",
        "seduir",
        "seducció",
        "segregar",
        "segregat",
        "aprofitar",
        "egoista",
        "egoisme",
        "senil",
        "sense sentit",
        "frase",
        "separatista",
        "sepsis",
        "sèptic",
        "segrest",
        "serè",
        "serp",
        "criat",
        "servir",
        "servil",
        "servitud",
        "revés",
        "sever",
        "aigües residuals",
        "clavegueram",
        "lamentable",
        "barraca",
        "grillons",
        "ombrejat",
        "tremolant",
        "inestable",
        "farsa",
        "ruïnes",
        "vergonya",
        "vergonyós",
        "descarat",
        "shanghai",
        "tauró",
        "fer miques",
        "destrossat",
        "cobert",
        "closca",
        "estanteria",
        "naufragi",
        "merda",
        "estremiment",
        "xoc",
        "de mala qualitat",
        "disparar",
        "tirar",
        "aixecament de botigues",
        "escassetat",
        "deficiència",
        "tir",
        "empènyer",
        "cridaner",
        "cridar",
        "estrident",
        "encongir-se",
        "encongit",
        "estremiment",
        "rebuig",
        "malalt",
        "malestar",
        "malalt",
        "malaltia",
        "tonto",
        "NO TRANSLATION",
        "pecaminós",
        "sinistre",
        "pecador",
        "pecar",
        "sirena",
        "Sissy",
        "escèptic",
        "incompleta",
        "esbiaixat",
        "skid",
        "Omet",
        "escaramussa",
        "fluix",
        "escòria",
        "slam",
        "calúmnia",
        "calúmnia",
        "boig",
        "matança",
        "escorxador",
        "matança",
        "esclau",
        "esclavitud",
        "matar",
        "assassí",
        "escurçó",
        "baboso",
        "lliscar",
        "escletxa",
        "NO TRANSLATION",
        "descuidat",
        "mandros",
        "slouch",
        "Slough",
        "lentitud",
        "fangs",
        "escletxa",
        "lenta",
        "barri baix",
        "caure",
        "boig",
        "boig",
        "puta",
        "astut",
        "cop",
        "petit",
        "aixafar",
        "esmicolat",
        "sorollós",
        "olor",
        "olorant",
        "somriure",
        "ferit",
        "fumador",
        "sofriment",
        "manchú",
        "presumible",
        "contraban",
        "contrabandista",
        "contraban",
        "smut",
        "atropellament",
        "snags",
        "serp",
        "trampa",
        "ronca",
        "roncant",
        "colar-se",
        "furtivament",
        "espiar-se",
        "esternudar",
        "snide",
        "snob",
        "remullar",
        "NO TRANSLATION",
        "socialista",
        "sòl",
        "embrutit",
        "somàtic",
        "sombre",
        "sutge",
        "hechicería",
        "sòrdid",
        "Dolor",
        "sorely",
        "dolor",
        "pena",
        "trist",
        "NO TRANSLATION",
        "sense ànima",
        "ànima bessona",
        "àcid",
        "assotar",
        "espasme",
        "escopir",
        "llança",
        "mota",
        "espectre",
        "espectral",
        "especulacions",
        "gastat",
        "spinster",
        "malgrat tot",
        "lamentable",
        "astilla",
        "dividir",
        "dividint",
        "espatllar",
        "spoiler",
        "parlava",
        "esponja",
        "espectacle",
        "esquinç",
        "festa",
        "Sprite",
        "espurio",
        "esclat",
        "ocupat",
        "sensual",
        "estripar",
        "calmar",
        "apunyalar",
        "sorprenent",
        "estancat",
        "taca",
        "obsolet",
        "tija",
        "estancament",
        "parada",
        "mirant",
        "crua",
        "sorpresa",
        "fam",
        "moren de fam",
        "morint de fam",
        "estacionari",
        "stave",
        "robar",
        "robatori",
        "sigil",
        "estereotip",
        "estereotipat",
        "estèril",
        "esterilitat",
        "popa",
        "rígid",
        "rigidesa",
        "sofocar",
        "sofocada",
        "estigma",
        "nascut mort",
        "picada",
        "picada",
        "taca",
        "pudor",
        "apestant",
        "Stint",
        "existències",
        "robat",
        "pedra",
        "apedrejat",
        "tamborets",
        "atur",
        "tempesta",
        "tempestuós",
        "tensió",
        "estret",
        "atrapat",
        "desconegut",
        "estrangular",
        "perdut",
        "estrès",
        "lluita",
        "colpejar",
        "tira",
        "franja",
        "despullat",
        "accident cerebrovascular",
        "lluita",
        "puntal",
        "congestionada",
        "ensopegar",
        "atordit",
        "atordit",
        "estúpid",
        "estupidesa",
        "estupor",
        "estil",
        "sotmetre",
        "assignatura",
        "sotmès",
        "subjecció",
        "submissió",
        "subordinat",
        "citació",
        "subsidència",
        "subsidi",
        "subsisteix",
        "sostreure",
        "subversió",
        "subversiu",
        "subvertir",
        "sucumbir",
        "xuclar",
        "aixovador",
        "demandar",
        "pateix",
        "malalt",
        "patiment",
        "asfixiant",
        "asfíxia",
        "suïcida",
        "suïcidi",
        "indignat",
        "convocatòria",
        "enfonsat",
        "superficial",
        "superflu",
        "supersticiosos",
        "suprimir",
        "supressió",
        "recàrrec",
        "sorollosa",
        "rendició",
        "rendint-se",
        "susceptible",
        "sospitós",
        "suspensió",
        "sospita",
        "sospitós",
        "hisop",
        "pantà",
        "pantà",
        "esvàstica",
        "inflor",
        "swig",
        "porc",
        "inflat",
        "símptoma",
        "síncope",
        "tabú",
        "taca",
        "NO TRANSLATION",
        "Enredat",
        "tardança",
        "tard",
        "tarifa",
        "manchar",
        "tarry",
        "sense sabor",
        "taunt",
        "impost",
        "burlar",
        "burlar",
        "tediós",
        "NO TRANSLATION",
        "Tempesta",
        "temptació",
        "habitatge",
        "terminal",
        "terminació",
        "termite",
        "terrible",
        "terror",
        "terrorisme",
        "terrorista",
        "aterrorizar",
        "tètanus",
        "tether",
        "robatori",
        "el teisme",
        "teocràtic",
        "lladre",
        "set",
        "espina",
        "espinós",
        "sense pensar",
        "thrash",
        "amenaça",
        "amenaça",
        "amenaçant",
        "trilla",
        "lladre",
        "accelerador",
        "brètol",
        "batec",
        "fulminant",
        "frustrar",
        "tiff",
        "tímid",
        "timidesa",
        "consells",
        "tirade",
        "cansat",
        "cansament",
        "cansat",
        "tit",
        "gripau",
        "tabac",
        "WC",
        "treballs",
        "tolerar",
        "mal de queixal",
        "turment",
        "trencat",
        "torpede",
        "torrid",
        "tort",
        "tortuós",
        "tortura",
        "tocat",
        "tàctil",
        "dur",
        "tòxic",
        "toxina",
        "tragèdia",
        "tràgic",
        "traïdor",
        "vagabund",
        "trànsit",
        "transgressió",
        "adorns",
        "trampes",
        "escombraries",
        "trashy",
        "traumàtic",
        "NO TRANSLATION",
        "travesty",
        "traïdor",
        "traïció",
        "traïció",
        "tremolant",
        "tremolor",
        "agitació",
        "transgressió",
        "tribulació",
        "tribunal",
        "truc",
        "trucs",
        "poc",
        "disparar",
        "troll",
        "problemàtic",
        "trompeta",
        "caure",
        "tumor",
        "tumor",
        "tumult",
        "tumultuós",
        "turbulència",
        "turbulent",
        "confusió",
        "contracció",
        "tifó",
        "tiràniques",
        "tirania",
        "tirà",
        "lletjor",
        "lleig",
        "úlcera",
        "posterior",
        "ultimàtum",
        "incapaç",
        "inacceptable",
        "inexplicable",
        "no aprovat",
        "sense enganxar",
        "inabastable",
        "poc atractiu",
        "no autoritzat",
        "inevitable",
        "ignorant",
        "insuportable",
        "incredulitat",
        "increïble",
        "no nascut",
        "increïble",
        "sense importar",
        "incert",
        "immutable",
        "impur",
        "incòmode",
        "inconcebible",
        "inconscient",
        "inconstitucional",
        "incontrolable",
        "descontrolat",
        "indecisos",
        "soscavat",
        "mal pagat",
        "de mida inferior",
        "indesitjable",
        "no desitjat",
        "desfer",
        "inquietud",
        "incòmode",
        "sense educació",
        "aturat",
        "desigual",
        "desigual",
        "inexplicable",
        "injust",
        "injustícia",
        "infidel",
        "desfavorable",
        "sense acabar",
        "implacable",
        "desafortunat",
        "hostil",
        "incomplert",
        "sense mobles",
        "impius",
        "ingrat",
        "infelicitat",
        "infeliç",
        "poc sa",
        "inactiu",
        "no important",
        "sense impressionar",
        "sense millorar",
        "desinformat",
        "no iniciat",
        "sense inspiració",
        "inintel·ligible",
        "sense intenció",
        "sense interès",
        "sense interès",
        "injust",
        "injustificable",
        "injustificat",
        "desconsiderat",
        "desconegut",
        "il·legal",
        "sense llicència",
        "mala sort",
        "inmanejable",
        "antinatural",
        "no oficial",
        "sense pagar",
        "desagradable",
        "impopular",
        "imprevisible",
        "sense preparació",
        "improductiu",
        "inútil",
        "sense protecció",
        "inèdit",
        "poc fiable",
        "no correspost",
        "indisciplinat",
        "insegur",
        "insatisfactori",
        "insatisfet",
        "desagradable",
        "sense escrúpols",
        "inestable",
        "desagradable",
        "poc sofisticat",
        "inefable",
        "inestable",
        "sense èxit",
        "inadequat",
        "sense segellar",
        "no suportat",
        "insostenible",
        "poc simpàtic",
        "indemne",
        "insostenible",
        "impensable",
        "inadequat",
        "sense precedents",
        "Sense títol",
        "desconegut",
        "sense compromís",
        "sense entrenament",
        "fals",
        "poc fiable",
        "injustificat",
        "sense rentar",
        "no desitjat",
        "malestar",
        "falta de voluntat",
        "imprudent",
        "inconscient",
        "indigne",
        "inflexible",
        "trastorn",
        "aixecament",
        "esclat",
        "molest",
        "eriçó",
        "urgent",
        "inútil",
        "Usurp",
        "Usurpat",
        "usura",
        "vacant",
        "buit",
        "vague",
        "vaguedat",
        "en va",
        "vampir",
        "desaparegut",
        "vanitat",
        "varicel",
        "varicosa",
        "vegetatiu",
        "vehement",
        "vendetta",
        "venjança",
        "venjoso",
        "verí",
        "venenoso",
        "verbositat",
        "verge",
        "vermí",
        "contra",
        "vertigen",
        "veto",
        "vici",
        "cruel",
        "víctima",
        "víctima",
        "bandit",
        "vilà",
        "venjatiu",
        "violació",
        "violència",
        "violent",
        "violentament",
        "escurçó",
        "virulència",
        "virus",
        "visita",
        "vixen",
        "volatilitat",
        "volcà",
        "vòmits",
        "vudú",
        "vulgar",
        "vulgaritat",
        "vulnerabilitat",
        "voltor",
        "gofres",
        "wail",
        "espera",
        "wallow",
        "NO TRANSLATION",
        "perdre",
        "volent",
        "guerra",
        "guardià",
        "articles de consum",
        "guerra",
        "guerrer",
        "avisar",
        "ur",
        "deformat",
        "verruga",
        "malbaratament",
        "desperdiciat",
        "inútil",
        "perdent",
        "aquós",
        "buidar",
        "debilitat",
        "feble",
        "debilitat",
        "desgast",
        "cansament",
        "cansament",
        "cansat",
        "males herbes",
        "plorar",
        "estrany",
        "weirdo",
        "NO TRANSLATION",
        "wench",
        "colpejar",
        "caprici",
        "grinyols",
        "fuet",
        "torbellino",
        "whisky",
        "puta",
        "malvat",
        "maldat",
        "salvatge",
        "gat salvatge",
        "incendi forestal",
        "voluntari",
        "escalfament",
        "boig",
        "wince",
        "bruixa",
        "bruixeria",
        "retirar",
        "marcir",
        "seca",
        "ai",
        "lamentable",
        "lamentablement",
        "paraules",
        "cuc",
        "desgastat",
        "preocupat",
        "preocupació",
        "preocupant",
        "pitjor",
        "empitjorament",
        "sense valor",
        "ferida",
        "interferència",
        "ira",
        "provoca",
        "naufragi",
        "destrossat",
        "clau anglesa",
        "lluita lliure",
        "desgraciat",
        "miserable",
        "mal",
        "malament",
        "injust",
        "erròniament",
        "forjat",
        "irritable",
        "xenofòbia",
        "badallar",
        "badall",
        "grit",
        "grocs",
        "yelp",
        "cremallera",
    ]
)

_ambivalent = set(
    [
        "abundància",
        "armat",
        "bàlsam",
        "presumir",
        "boig",
        "cuc de reserves",
        "Buck",
        "celebritat",
        "encantat",
        "elusió",
        "complicitat",
        "confessar",
        "astúcia",
        "depenent",
        "divers",
        "dominar",
        "interminable",
        "fer complir",
        "eròtic",
        "escapar",
        "sensació",
        "coquetejar",
        "calamarsa",
        "hedonisme",
        "el més alt",
        "humil",
        "immediatament",
        "immòbil",
        "ingressos",
        "infiltració",
        "influència",
        "intens",
        "interminable",
        "intervenció",
        "encaix",
        "liberal",
        "senyor",
        "maternal",
        "llevadora",
        "mare",
        "tassa",
        "notorietat",
        "omnipotència",
        "explosió",
        "excepcional",
        "desfilada",
        "parafraseja",
        "petroli",
        "presentació",
        "prodigal",
        "cita",
        "deliri",
        "regressiu",
        "torna a créixer",
        "queda",
        "jubilació",
        "reviure",
        "revolució",
        "espantaocells",
        "reclusió",
        "sensual",
        "espectacle",
        "columna vertebral",
        "esterlina",
        "suculent",
        "superstició",
        "supremacia",
        "envoltant",
        "sinònim",
        "Tastant",
        "joves",
        "tractar",
        "invicte",
        "desenfrenat",
        "inesperat",
        "inimaginable",
        "deslligar",
        "pujant",
        "votar",
        "pes",
        "anhel",
    ]
)



"""
@author: alfonso.semeraro@unito.it

"""

import spacy
import json
import os
import emoatlas
from nltk.stem.snowball import SnowballStemmer


def _load_dictionary(language, stem_or_lem="lemmatization"):
    """
    It loads the emotional lexicon for the required languages.

    Required arguments:
    ----------

    *language*:
        One of the languages supported by Spacy:
            Catalan, Chinese, Danish, Dutch, English, French, German, Greek, Japanese, Italian, Lithuanian,
            Macedonian, Norvegian, Polish, Portuguese, Romanian, Russian, Spanish.

    Returns:
    ----------
    *lang_df*:
        A pandas dataframe: the table that contains the association < word, emotion >.

    """

    try:
        if stem_or_lem == "lemmatization":
            with open(
                f"{emoatlas.__path__[0]}{os.sep}langs{os.sep}{language}.json", "r"
            ) as fr:
                lang_df = json.load(fr)

        elif stem_or_lem == "stemming":
            with open(
                f"{emoatlas.__path__[0]}{os.sep}langs{os.sep}{language}_stem.json", "r"
            ) as fr:
                lang_df = json.load(fr)

        return lang_df

    except:
        raise ValueError("Language not supported.")


def _load_idiomatic_tokens(language, stem_or_lem="lemmatization"):
    """
    It loads the lexicon of replacements of idiomatic expressions with tokens, for the required languages.

    Required arguments:
    ----------

    *language*:
        One of the languages supported by Spacy:
            Catalan, Chinese, Danish, Dutch, English, French, German, Greek, Japanese, Italian, Lithuanian,
            Macedonian, Norvegian, Polish, Portuguese, Romanian, Russian, Spanish.

    Returns:
    ----------
    *idiomatic_tokens*:
        A dict: the replacements with < idiomatic_expression, token >.

    """
    try:
        if stem_or_lem == "lemmatization":
            with open(
                f"{emoatlas.__path__[0]}{os.sep}langs{os.sep}{language}_idiomatic_tokens.json",
                "r",
            ) as fr:
                idiomatic_tokens = json.load(fr)

        elif stem_or_lem == "stemming":
            with open(
                f"{emoatlas.__path__[0]}{os.sep}langs{os.sep}{language}_stem_idiomatic_tokens.json",
                "r",
            ) as fr:
                idiomatic_tokens = json.load(fr)

        return idiomatic_tokens

    except:
        raise ValueError("Language not supported.")


def _load_spacy(language="english", model=None):
    """
    Returns a spacy model object depending on the input provided.
    If no spacy_model will be inputed, a spacy model will be loaded according with the language parameter.

    Required arguments:
    ----------

    *language*:
        Language of the text. Full support is offered for the languages supported by Spacy:
            Catalan, Chinese, Danish, Dutch, English, French, German, Greek, Japanese, Italian, Lithuanian,
            Macedonian, Norvegian, Polish, Portuguese, Romanian, Russian, Spanish.
        Limited support for other languages is available.  By default, English will be loaded.

    Returns:
    ----------
    *spacy_model*:
        spacy model loaded
    """
    if model is None:
        try:
            # Spacy model depends on language
            spacy_model_lang = _spacy_model_by_language(language)

            return spacy.load(spacy_model_lang)

        except:
            raise ValueError(
                "spacy_model must be either a string or a loaded Spacy model. Can't find Spacy model '{}' on your system. Please install a model from https://spacy.io/models.".format(
                    spacy_model_lang
                )
            )
    else:
        try:
            # if a model is specified, loads it directly without inferring it from language

            return spacy.load(model)

        except:
            raise ValueError(
                "spacy_model must be either a string or a loaded Spacy model. Can't find Spacy model '{}' on your system. Please install a model from https://spacy.io/models.".format(
                    model
                )
            )


def _spacy_model_by_language(language):

    if language == "catalan":
        return "ca_core_news_lg"
    if language == "chinese":
        return "zh_core_web_lg"
    if language == "danish":
        return "da_core_news_lg"
    if language == "dutch":
        return "nl_core_news_lg"
    if language == "english":
        return "en_core_web_lg"
    if language == "french":
        return "fr_core_news_lg"
    if language == "german":
        return "de_core_news_lg"
    if language == "greek":
        return "el_core_news_lg"
    if language == "italian":
        return "it_core_news_lg"
    if language == "japanese":
        return "ja_core_news_lg"
    if language == "lithuanian":
        return "lt_core_news_lg"
    if language == "macedonian":
        return "mk_core_news_lg"
    if language == "norwegian":
        return "nb_core_news_lg"
    if language == "polish":
        return "pl_core_news_lg"
    if language == "portuguese":
        return "pt_core_news_lg"
    if language == "romanian":
        return "ro_core_news_lg"
    if language == "russian":
        return "ru_core_news_lg"
    if language == "spanish":
        return "es_core_news_lg"


def _load_stemmer(language):

    try:
        stemmer = SnowballStemmer(language)
    except:
        raise ValueError("Language not supported.")

    return stemmer


def _emotion_model_resources(
    emotion_lexicon=None, emotion_model="plutchik", language="english"
):
    """
    Fetch the lexicon (if not provided by the user) and the emotion names list, depending on the emotion model required.

    Required arguments:
    ----------
    *emotion_lexicon*:
        A lexicon with every word-emotion association. Required format is a dict <word, emotion_list>.
        By default, the NRCLexicon will be loaded.

    *emotion_model*:
        A string, what emotion model to use. Default is 'plutchik', i.e. the Plutchik's wheel of emotions.

    *language*:
        Language of the text. Full support is offered for the languages supported by Spacy:
            Catalan, Chinese, Danish, Dutch, English, French, German, Greek, Japanese, Italian, Lithuanian,
            Macedonian, Norvegian, Polish, Portuguese, Romanian, Russian, Spanish.
        Limited support for other languages is available.

    Returns:
    ----------
    *emotion_lexicon*:
        A dict. For each word in the keys, the value is a list of emotions associated.

    *emotions*:
        A list of emotions, depending on the model.
    """

    if emotion_model == "plutchik":
        emotions = [
            "anger",
            "trust",
            "surprise",
            "disgust",
            "joy",
            "sadness",
            "fear",
            "anticipation",
        ]

        if not emotion_lexicon:
            emotion_lexicon = _load_dictionary(language)
            emotion_lexicon = (
                emotion_lexicon.groupby("word")["emotion"].apply(list).to_dict()
            )

        return emotion_lexicon, emotions


def _load_emojis(language):

    if language == "english":
        with open(f"{emoatlas.__path__[0]}{os.sep}langs{os.sep}emojis.json", "r") as fr:
            return json.load(fr)

    return {}


def _load_antonyms(language):

    if language == "catalan":
        from emoatlas.antonyms.catalan import _antonyms

        return _antonyms
    if language == "chinese":
        from emoatlas.antonyms.chinese import _antonyms

        return _antonyms
    if language == "danish":
        from emoatlas.antonyms.danish import _antonyms

        return _antonyms
    if language == "dutch":
        from emoatlas.antonyms.dutch import _antonyms

        return _antonyms
    if language == "english":
        from emoatlas.antonyms.english import _antonyms

        return _antonyms
    if language == "french":
        from emoatlas.antonyms.french import _antonyms

        return _antonyms
    if language == "german":
        from emoatlas.antonyms.german import _antonyms

        return _antonyms
    if language == "greek":
        from emoatlas.antonyms.greek import _antonyms

        return _antonyms
    if language == "italian":
        from emoatlas.antonyms.italian import _antonyms

        return _antonyms
    if language == "japanese":
        from emoatlas.antonyms.japanese import _antonyms

        return _antonyms
    if language == "lithuanian":
        from emoatlas.antonyms.lithuanian import _antonyms

        return _antonyms
    if language == "macedonian":
        from emoatlas.antonyms.macedonian import _antonyms

        return _antonyms
    if language == "norwegian":
        from emoatlas.antonyms.norwegian import _antonyms

        return _antonyms
    if language == "polish":
        from emoatlas.antonyms.polish import _antonyms

        return _antonyms
    if language == "portuguese":
        from emoatlas.antonyms.portuguese import _antonyms

        return _antonyms
    if language == "romanian":
        from emoatlas.antonyms.romanian import _antonyms

        return _antonyms
    if language == "russian":
        from emoatlas.antonyms.russian import _antonyms

        return _antonyms
    if language == "spanish":
        from emoatlas.antonyms.spanish import _antonyms

        return _antonyms


def _valences(language):

    if language == "catalan":
        from emoatlas.valence.catalan import _positive, _negative, _ambivalent

    elif language == "chinese":
        from emoatlas.valence.chinese import _positive, _negative, _ambivalent

    elif language == "danish":
        from emoatlas.valence.danish import _positive, _negative, _ambivalent

    elif language == "dutch":
        from emoatlas.valence.dutch import _positive, _negative, _ambivalent

    elif language == "english":
        from emoatlas.valence.english import _positive, _negative, _ambivalent

    elif language == "french":
        from emoatlas.valence.french import _positive, _negative, _ambivalent

    elif language == "german":
        from emoatlas.valence.german import _positive, _negative, _ambivalent

    elif language == "greek":
        from emoatlas.valence.greek import _positive, _negative, _ambivalent

    elif language == "italian":
        from emoatlas.valence.italian import _positive, _negative, _ambivalent

    elif language == "japanese":
        from emoatlas.valence.japanese import _positive, _negative, _ambivalent

    elif language == "lithuanian":
        from emoatlas.valence.lithuanian import _positive, _negative, _ambivalent

    elif language == "norwegian":
        from emoatlas.valence.norwegian import _positive, _negative, _ambivalent

    elif language == "polish":
        from emoatlas.valence.polish import _positive, _negative, _ambivalent

    elif language == "portuguese":
        from emoatlas.valence.portuguese import _positive, _negative, _ambivalent

    elif language == "romanian":
        from emoatlas.valence.romanian import _positive, _negative, _ambivalent

    elif language == "russian":
        from emoatlas.valence.russian import _positive, _negative, _ambivalent

    elif language == "spanish":
        from emoatlas.valence.spanish import _positive, _negative, _ambivalent

    elif language == "macedonian":
        from emoatlas.valence.macedonian import _positive, _negative, _ambivalent

    return _positive, _negative, _ambivalent



"""
@author: alfonso.semeraro@unito.it

"""

from emoatlas.resources import (
    _load_spacy,
    _load_dictionary,
    _load_emojis,
    _load_antonyms,
    _load_idiomatic_tokens,
    _load_stemmer,
)
import emoatlas.formamentis_edgelist as fme
import emoatlas.emo_scores as es
import emoatlas.baselines as bsl
import emoatlas.draw_plutchik as dp
from emoatlas.baselines import _load_lookup_table, _make_baseline
import emoatlas.draw_formamentis_force as dff
import emoatlas.draw_formamentis_bundling as dfb


class EmoScores:
    def __init__(self, language="english", spacy_model=None, emotion_model="plutchik"):

        # Basic imports
        self.language = language
        self._emotion_lexicon = _load_dictionary(language)
        if spacy_model is None:
            self._tagger = _load_spacy(language)
        else:
            self._tagger = _load_spacy(model=spacy_model)
        self._stemmer = None
        self._stem_or_lem = "lemmatization"
        self._emotionlist = None
        self._emojis_dict = _load_emojis(language)
        self._idiomatic_tokens = _load_idiomatic_tokens(language)

        # Formamentis imports
        self._antonyms = _load_antonyms(language)

        # Z-scores imports
        self._baseline = _make_baseline(
            language=self.language, emotion_lexicon=self._emotion_lexicon
        )
        self._lookup = _load_lookup_table(language=self.language)

        if emotion_model == "plutchik":
            self.emotionslist = [
                "anger",
                "trust",
                "surprise",
                "disgust",
                "joy",
                "sadness",
                "fear",
                "anticipation",
            ]
            self._emotion_model = "plutchik"

    def set_stemming_lemmatization(self, stem_or_lem="lemmatization"):

        self._emotion_lexicon = _load_dictionary(self.language, stem_or_lem)
        self._idiomatic_tokens = _load_idiomatic_tokens(self.language, stem_or_lem)
        self._stem_or_lem = stem_or_lem

        if stem_or_lem == "stemming" and self._stemmer is None:
            self._stemmer = _load_stemmer(self.language)

    def set_baseline(self, baseline=None):
        """
        Set a new emotion distribution as baseline to compute zscores.
        If no baseline is provided, a new one will be created from the default emotion lexicon loaded.

        Required arguments:
        ----------

        *baseline*:
            Either a list of lists, a text, or None.
            If baseline is a list of list, it contains the distribution of emotions of the text used as baseline.
            If baseline is a text, a new emotion distribution will be computed from it.
            If baseline is None, it will be computed the emotion distribution of the default emotion lexicon loaded.

        """
        self._baseline = bsl._make_baseline(
            baseline,
            emotion_lexicon=self._emotion_lexicon,
            tagger=self._tagger,
            emojis_dict=self._emojis_dict,
            idiomatic_tokens=self._idiomatic_tokens,
        )
        self._lookup = {}

    def emotions(
        self,
        obj,
        normalization_strategy="none",
        return_words=False,
        convert_emojis=True,
    ):
        """
        Count emotions in an input text or Formamentis Network.

        Required arguments:
        ----------

        *obj*:
            Either a string or a list of tuples, with the former being the text to extract emotion from,
            and the latter being the standard representation of a formamentis edgelist.

        *normalization_strategy*:
            A string, whether to normalize emotion scores over the number of words. Accepted values are:
                'none': no normalization at all
                'text_lenght': normalize emotion counts over the total text length
                'emotion_words': normalize emotion counts over the number of words associated to an emotion

        *return_words*:
            A bool. Whether to return a list of the words associated with each of the emotions, or just their count.

        *convert_emojis*:
            A bool. Whether to convert emojis in raw text to be processed, or not.


        Returns:
        ----------
        *emotions*:
            A dict. Keys are emotions, and values the scores.
        """

        model = self._tagger if self._stem_or_lem == "lemmatization" else self._stemmer

        return es._get_emotions(
            obj=obj,
            normalization_strategy=normalization_strategy,
            emotion_lexicon=self._emotion_lexicon,
            language=self.language,
            tagger=model,
            emotions=self.emotionslist,
            return_words=return_words,
            emojis_dict=self._emojis_dict,
            convert_emojis=convert_emojis,
            idiomatic_tokens=self._idiomatic_tokens,
        )

    def zscores(self, obj, baseline=None, n_samples=300, convert_emojis=True):
        """
        Checks the emotion distribution in an input text or Formamentis Network against a baseline, and returns the z-scores.

        Required arguments:
        ----------

        *obj*:
            Either a string or a list of tuples, with the former being the text to extract emotion from,
            and the latter being the standard representation of a formamentis edgelist.

        *baseline*:
            Either a list of lists, a text, or None.
            If baseline is a list of list, it contains the distribution of emotions of the text used as baseline.
            If baseline is a text, a new emotion distribution will be computed from it.
            If baseline is None, it will be computed the emotion distribution of the default emotion lexicon loaded.

        *n_samples*:
            An integer, how many time the baseline emotion distribution will be sampled before checking for z-scores.
            Default is 300.

        *convert_emojis*:
            A bool. Whether to convert emojis in raw text to be processed, or not.

        Returns:
        ----------
        *z-scores*:
            A dict. Keys are emotions, and values the z-scores.

        """

        model = self._tagger if self._stem_or_lem == "lemmatization" else self._stemmer

        if not baseline:
            if not self._baseline:
                self._baseline = bsl._make_baseline(
                    baseline=None,
                    tagger=model,
                    language=self.language,
                    emotion_lexicon=self._emotion_lexicon,
                )
            baseline = self._baseline
        else:
            baseline = bsl._make_baseline(
                baseline=baseline,
                tagger=model,
                language=self.language,
                emotion_lexicon=self._emotion_lexicon,
            )

        return es._zscores(
            obj,
            baseline=baseline,
            n_samples=n_samples,
            emotion_lexicon=self._emotion_lexicon,
            language=self.language,
            tagger=model,
            emotions=self.emotionslist,
            lookup=self._lookup,
            emojis_dict=self._emojis_dict,
            convert_emojis=convert_emojis,
            idiomatic_tokens=self._idiomatic_tokens,
        )

    def formamentis_network(
        self,
        text,
        target_word=None,
        keepwords=[],
        stopwords=[],
        max_distance=3,
        semantic_enrichment="synonyms",
        multiplex=False,
        with_type=False,
    ):
        """
        Extract a Formamentis Network from input text.

        Required arguments:
        ----------

        *text*:
            A string, the text to extract emotions from.

        *target_word*:
            A string or None. If a string and method is 'formamentis', it will be computed the emotion distribution
            only of the neighborhood of 'target_word' in the formamentis network.

        *keepwords*:
            A list. Words that shall be included in formamentis networks regardless from their part of speech. Default is an empty list.
            By default implementation, a pre-compiled list of negations and pronouns will be loaded and used as keepwords.

        *stopwords*:
            A list. Words that shall be discarded from formamentis networks regardless from their part of speech. Default is an empty list.
            If a word is both in stopwords and in keepwords, the word will be discarded.

        *max_distance*:
            An integer, by default 2. Links in the formamentis network will be established from each word to each neighbor within a distance
            defined by max_distance.

        *semantic_enrichment*:
            A str or a list of str. If 'synonyms', will be added semantic arcs between synonyms into the network. If 'hypernyms', will be
            added semantic arcs between hypernyms and hyponyms. Also ['synonyms', 'hypernyms'] is accepted.

        *multiplex*:
            A bool: whether to return different edgelist for different kinds of edges (syntactic, synonyms, hypernyms) or not. Default is False.


        Returns:
        ----------
        *fmn*:
            A Formamentis Network in the form of (Edges, Vertices).

        """

        return fme.get_formamentis_edgelist(
            text,
            language=self.language,
            spacy_model=self._tagger,
            stemmer=self._stemmer,
            stem_or_lem=self._stem_or_lem,
            target_word=target_word,
            keepwords=keepwords,
            stopwords=stopwords,
            antonyms=self._antonyms,
            max_distance=max_distance,
            semantic_enrichment=semantic_enrichment,
            multiplex=multiplex,
            idiomatic_tokens=self._idiomatic_tokens,
        )

    def draw_formamentis(
        self,
        fmn,
        layout="edge_bundling",
        highlight=[],
        thickness=1,
        ax=None,
        translated=False,
        alpha_syntactic=0.5,
        alpha_hypernyms=0.5,
        alpha_synonyms=0.5,
    ):
        """
        Represents a Formamentis Network in either a circular or force-based layout.

        Required arguments:
        ----------

        *fmn*:
            A Formamentis Network to visualize.

        *layout*:
            A str. Either "edge_bundling" for circular layout or "force_layout" for force-based layout.

        *highlight*:
            A list of the words to highlight in the network.

        *thickness*:
            A numeric. How thick must lines be drawn. Default is 1.

        *ax*:
            A matplotlib axes to draw the network on. If none is provided, a new one will be created.

        *translated*:
            A boolean value. True for english-translated nodes, False for original node labels. Default is False.

        *alpha_syntactic*:
            A numeric. Alpha value for syntactic edges, must be between 0.0 and 1.0

        *alpha_hypernyms*:
            A numeric. Alpha value for hypernyms edges, must be between 0.0 and 1.0

        *alpha_synonyms*:
            A numeric. Alpha value for synonyms edges, must be between 0.0 and 1.0
        """

        # Check if alpha values are within the range [0.0, 1.0]
        if not (0.0 <= alpha_syntactic <= 1.0):
            raise ValueError("Alpha value for syntactic must be between 0.0 and 1.0")
        if not (0.0 <= alpha_hypernyms <= 1.0):
            raise ValueError("Alpha value for hypernyms must be between 0.0 and 1.0")
        if not (0.0 <= alpha_synonyms <= 1.0):
            raise ValueError("Alpha value for synonyms must be between 0.0 and 1.0")

        if layout == "force_layout":
            dff.draw_formamentis_force_layout(
                fmn.edges,
                highlight=highlight,
                language=self.language,
                thickness=thickness,
                ax=ax,
                translated=translated,
                alpha_syntactic=alpha_syntactic,
                alpha_hypernyms=alpha_hypernyms,
                alpha_synonyms=alpha_synonyms,
            )
        elif layout == "edge_bundling":
            dfb.draw_formamentis_circle_layout(
                fmn,
                highlight=highlight,
                language=self.language,
                thickness=thickness,
                ax=ax,
                translated=translated,
                alpha_syntactic=alpha_syntactic,
                alpha_hypernyms=alpha_hypernyms,
                alpha_synonyms=alpha_synonyms,
            )

    def draw_statistically_significant_emotions(self, obj):
        """
        Computes how statistically significantly higher or lower is each emotion in the input text or Formamentis Network.
        It draws the Plutchik's flower highlighting only emotions over/under represented w.r.t. a neutral baseline.
        This function is a wrapper of
            zs = zscores(obj)
            draw_plucthik(zs, reject_range = [-1.96, 1.96])

        Required arguments:
        ----------

        *obj*:
            A str or a Formamentis Network to search emotions in.

        *reject_range*:
            A threshold for significance of zscores. A zscore higher (lower) than 1.96 (-1.96) means that an emotion is
            statistically over (under) represented (p-value = 0.05).
        """
        zs = self.zscores(obj)
        self.draw_plutchik(zs, reject_range=[-1.96, 1.96])

    def draw_formamentis_flower(
        self,
        text,
        target_word=None,
        keepwords=[],
        stopwords=[],
        max_distance=3,
        semantic_enrichment=[],
        reject_range=(-1.96, 1.96),
    ):
        """
        Draw a Plutchik's wheel of emotions based on a Formamentis Network built upon input text.
        This function is a wrapper of
            fmn = formamentis_network(text, target_word = target_word)
            zs = zscores(fmn)
            draw_plutchik(zs, reject_range = (-1.96, 1.96))

        Required arguments:
        ----------

        *text*:
            A string, the text to extract the Formamentis_Network from.

        *target_word*:
            A string or None. If a string and method is 'formamentis', it will be computed the emotion distribution
            only of the neighborhood of 'target_word' in the formamentis network.

        *keepwords*:
            A list. Words that shall be included in formamentis networks regardless from their part of speech. Default is an empty list.
            By default implementation, a pre-compiled list of negations and pronouns will be loaded and used as keepwords.

        *stopwords*:
            A list. Words that shall be discarded from formamentis networks regardless from their part of speech. Default is an empty list.
            If a word is both in stopwords and in keepwords, the word will be discarded.

        *max_distance*:
            An integer, by default 2. Links in the formamentis network will be established from each word to each neighbor within a distance
            defined by max_distance.

        *semantic_enrichment*:
            A str or a list of str. If 'synonyms', will be added semantic arcs between synonyms into the network. If 'hyperonyms', will be
            added semantic arcs between hyperonyms and hyponyms. Also ['synonyms', 'hyperonyms'] is accepted.


        *reject_range*:
            A threshold for significance of zscores. A zscore higher (lower) than 1.96 (-1.96) means that an emotion is
            statistically over (under) represented (p-value = 0.05).

        """
        fmn = self.formamentis_network(
            text,
            target_word=target_word,
            keepwords=keepwords,
            stopwords=stopwords,
            semantic_enrichment=semantic_enrichment,
            max_distance=max_distance,
        )

        zs = self.zscores(fmn)
        self.draw_plutchik(zs, reject_range=(-1.96, 1.96))

    def draw_plutchik(
        self,
        scores,
        ax=None,
        rescale=False,
        reject_range=None,
        highlight="all",
        show_intensity_levels="none",
        font=None,
        fontweight="light",
        fontsize=15,
        show_coordinates=True,
        show_ticklabels=False,
        ticklabels_angle=0,
        ticklabels_size=11,
        height_width_ratio=1,
        title=None,
        title_size=None,
    ):
        """
        Draw the emotions or dyads Plutchik flower.
        Full details at https://github.com/alfonsosemeraro/pyplutchik/blob/master/Documentation.md

        Required arguments:
        ----------

        *scores*:
            A dictionary with emotions or dyads.
            For each entry, values accepted are a 3-values iterable (for emotions only) or a scalar value between 0 and 1.
            The sum of the 3-values iterable values must not exceed 1, and no value should be negative.
            See emo_params() and dyad_params() for accepted keys.

            Emotions and dyads are mutually exclusive. Different kinds of dyads are mutually exclusive.

        *ax*:
            Axes to draw the coordinates.

        *rescale*:
            Either None or a 2-item tuple, with minimum and maximum value of the printable area.

        *reject_range*:
            A 2-item tuple. All petal scores that fall within the range must be considered non-interesting, thus drawed in grey.
            Default is None (no range at all).

        *highlight*:
            A string or a list of main emotions to highlight. If a list of emotions is given, other emotions will be shadowed.
            Default is 'all'.

        *show_intensity_levels*:
            A string or a list of main emotions. It shows all three intensity scores for each emotion in the list,
            and for the others cumulative scores. Default is 'none'.

        *font*:
            Font of text. Default is sans-serif.

        *fontweight*:
            Font weight of text. Default is light.

        *fontsize*:
            Font size of text. Default is 15.

        *show_coordinates*:
            A boolean, wether to show polar coordinates or not.

        *show_ticklabels*:
            Boolean, wether to show tick labels under Joy petal. Default is False.

        *ticklabels_angle*:
            How much to rotate tick labels from y=0. Value should be given in radians. Default is 0.

        *ticklabels_size*:
            Size of tick labels. Default is 11.

        *height_width_ratio*:
            Ratio between height and width of the petal. Lower the ratio, thicker the petal. Default is 1.

        *title*:
            Title for the plot.

        *title_size*:
            Size of the title. Default is font_size.

        Returns:
        ----------
        *ax*:
            The input Axes modified, if provided, otherwise a new generated one.

        """

        dp.draw_plutchik(
            scores,
            ax=ax,
            rescale=rescale,
            reject_range=reject_range,
            highlight=highlight,
            show_intensity_levels=show_intensity_levels,
            font=font,
            fontweight=fontweight,
            fontsize=fontsize,
            show_coordinates=show_coordinates,
            show_ticklabels=show_ticklabels,
            ticklabels_angle=ticklabels_angle,
            ticklabels_size=ticklabels_size,
            height_width_ratio=height_width_ratio,
            title=title,
            title_size=title_size,
        )
